package com.ruoyi.web.controller.oa;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.oa.domain.CmcBorrow;
import com.ruoyi.oa.service.ICmcBorrowService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * cmc借款申请Controller
 * 
 * @author cmc
 * @date 2024-04-07
 */
@RestController
@RequestMapping("/oa/borrow")
public class CmcBorrowController extends BaseController
{
    @Autowired
    private ICmcBorrowService cmcBorrowService;

    /**
     * 查询cmc借款申请列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CmcBorrow cmcBorrow)
    {
        startPage();
        List<CmcBorrow> list = cmcBorrowService.selectCmcBorrowList(cmcBorrow);
        return getDataTable(list);
    }

    /**
     * 导出cmc借款申请列表
     */
    @Log(title = "cmc借款申请", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmcBorrow cmcBorrow)
    {
        List<CmcBorrow> list = cmcBorrowService.selectCmcBorrowList(cmcBorrow);
        ExcelUtil<CmcBorrow> util = new ExcelUtil<CmcBorrow>(CmcBorrow.class);
        util.exportExcel(response, list, "cmc借款申请数据");
    }

    /**
     * 获取cmc借款申请详细信息
     */
    @GetMapping(value = "/{borrowJd}")
    public AjaxResult getInfo(@PathVariable("borrowJd") String borrowJd)
    {
        return success(cmcBorrowService.selectCmcBorrowByBorrowJd(borrowJd));
    }

    /**
     * 新增cmc借款申请
     */
    @Log(title = "cmc借款申请", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmcBorrow cmcBorrow)
    {
        return toAjax(cmcBorrowService.insertCmcBorrow(cmcBorrow));
    }

    /**
     * 修改cmc借款申请
     */
    @Log(title = "cmc借款申请", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmcBorrow cmcBorrow)
    {
        return toAjax(cmcBorrowService.updateCmcBorrow(cmcBorrow));
    }

    /**
     * 删除cmc借款申请
     */
    @Log(title = "cmc借款申请", businessType = BusinessType.DELETE)
	@DeleteMapping("/{borrowJds}")
    public AjaxResult remove(@PathVariable String[] borrowJds)
    {
        return toAjax(cmcBorrowService.deleteCmcBorrowByBorrowJds(borrowJds));
    }
}
