package com.ruoyi.web.controller.oa;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.oa.domain.CmcProjectComment;
import com.ruoyi.oa.service.ICmcProjectCommentService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * cmc项目审批Controller
 * 
 * @author cmc
 * @date 2024-04-02
 */
@RestController
@RequestMapping("/oa/projectComment")
public class CmcProjectCommentController extends BaseController
{
    @Autowired
    private ICmcProjectCommentService cmcProjectCommentService;

    /**
     * 查询cmc项目审批列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CmcProjectComment cmcProjectComment)
    {
        startPage();
        List<CmcProjectComment> list = cmcProjectCommentService.selectCmcProjectCommentList(cmcProjectComment);
        return getDataTable(list);
    }

    /**
     * 导出cmc项目审批列表
     */
    @Log(title = "cmc项目审批", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmcProjectComment cmcProjectComment)
    {
        List<CmcProjectComment> list = cmcProjectCommentService.selectCmcProjectCommentList(cmcProjectComment);
        ExcelUtil<CmcProjectComment> util = new ExcelUtil<CmcProjectComment>(CmcProjectComment.class);
        util.exportExcel(response, list, "cmc项目审批数据");
    }

    /**
     * 获取cmc项目审批详细信息
     */
    @GetMapping(value = "/{projectId}")
    public AjaxResult getInfo(@PathVariable("projectId") String projectId)
    {
        return success(cmcProjectCommentService.selectCmcProjectCommentByProjectId(projectId));
    }

    /**
     * 新增cmc项目审批
     */
    @Log(title = "cmc项目审批", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmcProjectComment cmcProjectComment)
    {
        return toAjax(cmcProjectCommentService.insertCmcProjectComment(cmcProjectComment));
    }

    /**
     * 修改cmc项目审批
     */
    @Log(title = "cmc项目审批", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmcProjectComment cmcProjectComment)
    {
        return toAjax(cmcProjectCommentService.updateCmcProjectComment(cmcProjectComment));
    }

    /**
     * 删除cmc项目审批
     */
    @Log(title = "cmc项目审批", businessType = BusinessType.DELETE)
	@DeleteMapping("/{projectIds}")
    public AjaxResult remove(@PathVariable String[] projectIds)
    {
        return toAjax(cmcProjectCommentService.deleteCmcProjectCommentByProjectIds(projectIds));
    }
}
