package com.ruoyi.web.controller.oa;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.oa.domain.CmcProjectWorker;
import com.ruoyi.oa.service.ICmcProjectWorkerService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * cmc项目人员Controller
 * 
 * @author cmc
 * @date 2024-03-26
 */
@RestController
@RequestMapping("/oa/projectWorker")
public class CmcProjectWorkerController extends BaseController
{
    @Autowired
    private ICmcProjectWorkerService cmcProjectWorkerService;

    /**
     * 查询cmc项目人员列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CmcProjectWorker cmcProjectWorker)
    {
        startPage();
        List<CmcProjectWorker> list = cmcProjectWorkerService.selectCmcProjectWorkerList(cmcProjectWorker);
        return getDataTable(list);
    }

    /**
     * 导出cmc项目人员列表
     */
    @Log(title = "cmc项目人员", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmcProjectWorker cmcProjectWorker)
    {
        List<CmcProjectWorker> list = cmcProjectWorkerService.selectCmcProjectWorkerList(cmcProjectWorker);
        ExcelUtil<CmcProjectWorker> util = new ExcelUtil<CmcProjectWorker>(CmcProjectWorker.class);
        util.exportExcel(response, list, "cmc项目人员数据");
    }

    /**
     * 获取cmc项目人员详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(cmcProjectWorkerService.selectCmcProjectWorkerById(id));
    }

    /**
     * 新增cmc项目人员
     */
    @Log(title = "cmc项目人员", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmcProjectWorker cmcProjectWorker)
    {
        return toAjax(cmcProjectWorkerService.insertCmcProjectWorker(cmcProjectWorker));
    }

    /**
     * 修改cmc项目人员
     */
    @Log(title = "cmc项目人员", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmcProjectWorker cmcProjectWorker)
    {
        return toAjax(cmcProjectWorkerService.updateCmcProjectWorker(cmcProjectWorker));
    }

    /**
     * 删除cmc项目人员
     */
    @Log(title = "cmc项目人员", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(cmcProjectWorkerService.deleteCmcProjectWorkerByIds(ids));
    }
}
