package com.ruoyi.oa.service;

import java.util.List;
import com.ruoyi.oa.domain.CmcPrice;

/**
 * cmc结算单价Service接口
 * 
 * @author cmc
 * @date 2024-03-21
 */
public interface ICmcPriceService 
{
    /**
     * 查询单价表
     *
     * @param id 单价表ID
     * @return 单价表
     */
    public CmcPrice selectCmcPriceById(Long id);

    /**
     * 查询单价表列表
     *
     * @param cmcPrice 单价表
     * @return 单价表集合
     */
    public List<CmcPrice> selectCmcPriceList(CmcPrice cmcPrice);

    /**
     * 根据工作类别查询单价表
     *
     * @param workType 工作类别
     * @return 单价表
     */
    public List<CmcPrice> selectCmcPriceByWorkType(String workType);

    /**
     * 根据工作内容查询单价表
     *
     * @param workItem 工作内容
     * @return 单价表
     */
    public List<CmcPrice> selectCmcPriceByWorkItem(String workItem);

    /**
     * 根据比例等级查询出单位、一般地类、复杂地类
     *
     * @param workItem 工作内容
     * @param subItem 内容细项
     * @param scaleGrade 比例等级
     * @return 单价表
     */
    public List<CmcPrice> selectCmcPriceByScaleGrade(String workItem, String subItem, String scaleGrade);

    /**
     * 新增单价表
     *
     * @param cmcPrice 单价表
     * @return 结果
     */
    public int insertCmcPrice(CmcPrice cmcPrice);

    /**
     * 修改单价表
     *
     * @param cmcPrice 单价表
     * @return 结果
     */
    public int updateCmcPrice(CmcPrice cmcPrice);

    /**
     * 批量删除单价表
     *
     * @param ids 需要删除的单价表ID
     * @return 结果
     */
    public int deleteCmcPriceByIds(Long[] ids);

    /**
     * 删除单价表信息
     *
     * @param id 单价表ID
     * @return 结果
     */
    public int deleteCmcPriceById(Long id);
}
