-- ----------------------------
-- 1、部门表
-- ----------------------------
drop table if exists sys_dept;
create table sys_dept (
  dept_id           bigint(20)      not null auto_increment    comment '部门id',
  parent_id         bigint(20)      default 0                  comment '父部门id',
  ancestors         varchar(50)     default ''                 comment '祖级列表',
  dept_name         varchar(30)     default ''                 comment '部门名称',
  order_num         int(4)          default 0                  comment '显示顺序',
  leader            varchar(20)     default null               comment '负责人',
  phone             varchar(11)     default null               comment '联系电话',
  email             varchar(50)     default null               comment '邮箱',
  status            char(1)         default '0'                comment '部门状态（0正常 1停用）',
  del_flag          char(1)         default '0'                comment '删除标志（0代表存在 2代表删除）',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time 	    datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间',
  primary key (dept_id)
) engine=innodb auto_increment=200 comment = '部门表';

-- ----------------------------
-- 初始化-部门表数据
-- ----------------------------
insert into sys_dept values (100, 0, '0', '四川中水成勘院测绘工程有限责任公司', 0, null, null, null, '0', '0', 'admin', '2024-01-04 11:34:52', null, null);
insert into sys_dept values (101, 100, '0,100', '董事会', 1, null, null, null, '0', '0', 'admin', '2024-01-04 11:34:52', null, null);
insert into sys_dept values (102, 100, '0,100', '经营管理层', 2, null, null, null, '0', '0', 'admin', '2024-01-04 11:36:52', null, null);
insert into sys_dept values (103, 100, '0,100', '综合事务部', 3, null, null, null, '0', '0', 'admin', '2024-01-04 11:38:16', null, null);
insert into sys_dept values (104, 100, '0,100', '经营发展部', 4, null, null, null, '0', '0', 'admin', '2024-01-04 11:38:32', null, null);
insert into sys_dept values (105, 100, '0,100', '财务部', 5, null, null, null, '0', '0', 'admin', '2024-01-04 11:38:44', null, null);
insert into sys_dept values (106, 100, '0,100', '项目管理部', 6, null, null, null, '0', '0', 'admin', '2024-01-04 11:39:02', null, null);
insert into sys_dept values (107, 100, '0,100', '激光技术中心', 7, null, null, null, '0', '0', 'admin', '2024-01-04 11:39:21', null, null);
insert into sys_dept values (108, 100, '0,100', '地理信息中心', 8, null, null, null, '0', '0', 'admin', '2024-01-04 11:39:31', null, null);
insert into sys_dept values (109, 100, '0,100', '技术质量部', 9, null, null, null, '0', '0', 'admin', '2024-01-04 11:39:50', null, null);
insert into sys_dept values (110, 100, '0,100', '航测遥感中心', 10, null, null, null, '0', '0', 'admin', '2024-01-04 11:40:03', null, null);
insert into sys_dept values (111, 100, '0,100', '测绘工程中心', 11, null, null, null, '0', '0', 'admin', '2024-01-04 11:40:16', null, null);
insert into sys_dept values (112, 100, '0,100', '工程监测中心', 12, null, null, null, '0', '0', 'admin', '2024-01-04 11:40:35', null, null);
insert into sys_dept values (113, 100, '0,100', '勘察设计事业部', 13, null, null, null, '0', '0', 'admin', '2024-01-04 11:40:59', null, null);
insert into sys_dept values (114, 100, '0,100', '测量中心', 14, null, null, null, '0', '0', 'admin', '2024-01-04 11:41:14', null, null);
insert into sys_dept values (115, 100, '0,100', '重庆分公司', 15, null, null, null, '0', '0', 'admin', '2024-01-04 11:42:31', null, null);
insert into sys_dept values (116, 100, '0,100', '德方子公司', 16, null, null, null, '0', '0', 'admin', '2024-01-04 11:42:56', null, null);
insert into sys_dept values (117, 100, '0,100', '云南子公司', 17, null, null, null, '0', '0', 'admin', '2024-01-04 11:43:16', null, null);


-- ----------------------------
-- 2、用户信息表
-- ----------------------------
drop table if exists sys_user;
create table sys_user (
  user_id           bigint(20)      not null auto_increment    comment '用户ID',
  dept_id           bigint(20)      default null               comment '部门ID',
  user_name         varchar(30)     not null                   comment '用户账号',
  nick_name         varchar(30)     not null                   comment '用户昵称',
  user_type         varchar(2)      default '00'               comment '用户类型（00系统用户）',
  email             varchar(50)     default ''                 comment '用户邮箱',
  phonenumber       varchar(11)     default ''                 comment '手机号码',
  sex               char(1)         default '0'                comment '用户性别（0男 1女 2未知）',
  avatar            varchar(100)    default ''                 comment '头像地址',
  password          varchar(100)    default ''                 comment '密码',
  status            char(1)         default '0'                comment '帐号状态（0正常 1停用）',
  del_flag          char(1)         default '0'                comment '删除标志（0代表存在 2代表删除）',
  login_ip          varchar(128)    default ''                 comment '最后登录IP',
  login_date        datetime                                   comment '最后登录时间',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time       datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间',
  remark            varchar(500)    default null               comment '备注（作业类别）',
  pm_level			char(1)			default null			   comment '项目经理级别（0一、1二、2三）',
  titles			varchar(9)		default null			   comment '技术职称（0正高、1副高、2中级、3助工、4注测、5注规、6注岩、7注安、8注会）',
  engineer_level	char(1)			default null			   comment '工程师岗级（0一级、1二级、2三级、3四级、4五级、5六级）',
  post_level		char(1)			default null			   comment '岗级（0一岗、1二岗、2三岗、3四岗、4五岗、5六岗、6七岗、7八岗）',
  salary_level		char(1)			default null			   comment '薪档（0一级、1二级、2三级、3四级、4五级、5六级、6七级、7八级）',
  entry_date		datetime								   comment '入职时间',
  age				int											comment '年龄',
  update_reason		char(1) 		default null				comment '更新原因（0误录修改、1正常调整）',
  primary key (user_id)
) engine=innodb auto_increment=1 comment = '用户信息表';

-- ----------------------------
-- 初始化-用户信息表数据
-- ----------------------------
insert into sys_user values (1, 103, 'admin', 'admin', '00', '', '15888888888', '1', '', '$2a$10$7JB720yubVSZvUI0rEqK/.VqGOZTH.ulu33dHOiBE8ByOhJIrdAu2', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, '管理员', null, null, null, null, null, null, null, null);
insert into sys_user values (2, 101, '13982275233', '刘光庆', '00', '', '13982275233', '0', '', '$2a$10$pcdc8BbNDNiWaQUU14BC3eGWxB4sSJOQZBL9QFftkhkjcbYU03DNi', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (3, 101, '13808211356', '向发廷', '00', '', '13808211356', '0', '', '$2a$10$zynAhjpaUxERmH4yo9R9s.O.oUgpxwRKtKA6X74ncn0z1ajFxqMyq', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (4, 101, '13608089391', '王 渊', '00', '', '13608089391', '0', '', '$2a$10$sKWfjdS0vJMA194/pu9q/e8Etz6kNBTzlURGDtKreBE8oHsRWP9hW', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (5, 101, '13808210959', '饶兴贵', '00', '', '13808210959', '0', '', '$2a$10$oyppe5szUKvS7tmJGPEMAOokXiWFJys5MMfOWFc6.ETpyBgCDo/42', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (6, 101, '13308085432', '阴学军', '00', '', '13308085432', '0', '', '$2a$10$nb/NapsXWQd/IfPbrqXKjefXlOKmRB5ScgVneGxPgEyo4FZ8.RMOi', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (7, 101, '13908178105', '樊宽林', '00', '', '13908178105', '0', '', '$2a$10$wnFsEXdHdJCgVYffXW7FRerg0c3v3S.aVqtdiWrtSAt9KntmW6iIu', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (8, 103, '18034708068', '徐 婷', '00', '', '18034708068', '1', '', '$2a$10$3NJkNMrq0/vwnw5E3z6wI.TutQnqhwSuMFDPxV/OMe9IXt0fTobNW', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (9, 102, '13880963113', '陈 洪', '00', '', '13880963113', '0', '', '$2a$10$xVZmDdG0DUlGjuGMFi6WEem4pWuLKlqrg27VuBRbn3vfKq8ATWzVa', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (10, 102, '13981868188', '刘 非', '00', '', '13981868188', '0', '', '$2a$10$XCXSEHjvWp9IFbQIXfh/gu5i8R87DjKMHsEu.qioLaZLVDB3wr1z2', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (11, 102, '13882236733', '杨 卫', '00', '', '13882236733', '0', '', '$2a$10$buRf8Vh0f4./GVx9WV6zkO1LOKSIEnTK4tzXefEh6gcY2JfcI4gPO', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (12, 102, '13980583883', '宁 瑶', '00', '', '13980583883', '0', '', '$2a$10$srx9flT57EE/f2euaLgrIeud6Ujnz3HS3qfNYm7DXFY6XZ5p5Aai2', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (13, 104, '18190819097', '贾春华', '00', '', '18190819097', '0', '', '$2a$10$QSI1Pl1YK6kGt0zLDNv1COQyK8UDLWhBq26QSXEPpikIDArtqjeau', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (14, 105, '15928150405', '刘 楠', '00', '', '15928150405', '0', '', '$2a$10$6tmHn6r5Dy6/qdu/ZotiSObzEr7zymkKL/g/VkcdUjV16OezZFALu', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (15, 103, '13678018998', '张明勇', '00', '', '13678018998', '0', '', '$2a$10$TKhy.bdUf4CmSN4nnVGZIeuQvtaFc1V/cXKT87sCjpOwvLOGpDuC.', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (16, 103, '13683488600', '陈建贤', '00', '', '13683488600', '0', '', '$2a$10$/2zL9VLX21iPxTVPklI11uOanp0bcR90mgCc9tIz6.Ux1/tegzFBG', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (17, 103, '13438165216', '张国芳', '00', '', '13438165216', '1', '', '$2a$10$sKkER/2RwOhIcufS8ceg..D9TchtO/R4nFCP1cDpW4BsS47TcqqRC', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (18, 103, '15181125323', '简   鑫', '00', '', '15181125323', '1', '', '$2a$10$v2mVQvW5BsZnrxJ6j.AHRebGVQMRI3jaDlX0lDQnpBD.Y86VSnf9K', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (19, 103, '13378256139', '谢辉波', '00', '', '13378256139', '0', '', '$2a$10$mZT.3thlsNmtiGXrgJxIm.QbktUAa9blLqwOq7LhGfy1XG1xnAzEm', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (20, 104, '13550342375', '李胜才', '00', '', '13550342375', '0', '', '$2a$10$lUhqpfwHzoVXPDC6qRu8su8HWlLJ49SCEo1NDXyFf2q5C8hThZbXi', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (21, 104, '13568885428', '杨   俊', '00', '', '13568885428', '0', '', '$2a$10$CSpKNIxy1hlgONyLZNk9hupaQXiwpGEJYv8DFcSebuIp81J6aheeO', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (22, 104, '13882200825', '夏   夏', '00', '', '13882200825', '0', '', '$2a$10$WMD98fLsImPZ9rJwyIely.j5AKiQyUt/I3qT/Xcg5EdQCIkxx4kq2', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (23, 104, '18373705527', '柯   枭', '00', '', '18373705527', '1', '', '$2a$10$EMikBVL2M4b97n.MJmMCNO1YiFl49bjWWXZkFDZqvVkOpYhb5FEe6', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (24, 104, '18202833529', '黎   超', '00', '', '18202833529', '0', '', '$2a$10$MkPiNt69sG3HQg9EY3cpv.0Sw1iq53NMq/kdplK9W8ohqqY/dlUxC', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (25, 104, '13111885671', '刘   兴', '00', '', '13111885671', '0', '', '$2a$10$Ag2jfz8ppoSP4bpohVVD1evq8glP6O4tY0HD9DoXXhsPpxSP8egSy', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (26, 104, '18782949671', '梁   洁', '00', '', '18782949671', '1', '', '$2a$10$BZurM7Hzy/aquuAlLkk/pOD.y0Ks.BtYcCTTyEwtJHY3QEgFdwRBe', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (27, 104, '18681251027', '高天沄', '00', '', '18681251027', '0', '', '$2a$10$xk96PJpjcUIWEo9RTTOKYubqeSXETSUSbRYFjpCgSr1z9PPKUSKsu', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (28, 105, '18780223280', '周文婷*', '00', '', '18780223280', '1', '', '$2a$10$pg.prMidA.76KkPRsZsOQuKStpl74J29heNpxCtJbZqDl7i9DjIuu', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (29, 105, '18202802155', '彭   敏', '00', '', '18202802155', '1', '', '$2a$10$ozjePPQbsp9YORLj7r4.K.lTC/9E/ANgDsOHsEyHlQ9DP2MtggiAO', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (30, 105, '13699682119', '苟   丹', '00', '', '13699682119', '1', '', '$2a$10$Jt.lg9CXVwlm0puSYFS6IOjxrSPAAHuf5gFmRtRX89IAwJlL8bm4e', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (31, 105, '15102831685', '宋丹丹', '00', '', '15102831685', '1', '', '$2a$10$/j4MpWKxCUekgxiTD1yyyOpOVJme5YbfJz042FuNJLuccxkC2yJSm', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (32, 106, '18828096127', '朱   静', '00', '', '18828096127', '0', '', '$2a$10$PrXuWRk4u9d05TNI9MAGjeGwmsSglOtGNKX.fjDuRwmTfVSFr4x9C', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (33, 106, '13882148315', '陈尚云', '00', '', '13882148315', '0', '', '$2a$10$I7CDnjCXqmbFmxdgcsoZ/uhgvEahRGZ/u3P4bdIU1Kic49Itu97JG', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (34, 106, '18113169528', '蒲   帆', '00', '', '18113169528', '0', '', '$2a$10$Z.3Y46kvgMCHpVSsXl3WJO4OOLJhr5IlzXTQqWx1a8yR1HaJQJQQW', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (35, 106, '18408201550', '邹帅民', '00', '', '18408201550', '0', '', '$2a$10$VC/JGLy.P6yJ5LJHmuq2dur.wnHYDzzxjyaizC8fYVNRq5DBmjjIm', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (36, 106, '13808178930', '周   芝', '00', '', '13808178930', '1', '', '$2a$10$4SuEJ.5YZSnk3UlpISWBmer7UZVMBKuMNBiG2/lUKafwNr1jI1UF2', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (37, 106, '18780290087', '苟   旭', '00', '', '18780290087', '0', '', '$2a$10$QCU/ERPaKSs5CAuWWB2WZ.13fxht6GKgGORCBS8DUy3qBmJybgzM.', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (38, 107, '18280462009', '刘媛媛', '00', '', '18280462009', '1', '', '$2a$10$SWNBLt43nQQJPC58DZmZcuHqkhre8lOMfl87AnM5UKuMrMfuPpaO6', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (39, 107, '18200194440', '吴   振', '00', '', '18200194440', '0', '', '$2a$10$a3ozNbqM6BYYISEJGIpx5O83L1RpMXNc4A9gpPu93qZ9PahUzx24u', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (40, 107, '15892280776', '王   刚', '00', '', '15892280776', '0', '', '$2a$10$ulhCOUUylhfnX7iccme6I.zpwLdnvU3zXXuMJ9LtRILnviD6Pvg9u', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (41, 107, '18140026972', '朱倪强', '00', '', '18140026972', '0', '', '$2a$10$HLRPkMz/orRnHouLjKNoH.Mn..dH97urH6up1x5AO0ZmtL64wp5XG', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (42, 107, '18408248664', '李   圆', '00', '', '18408248664', '1', '', '$2a$10$nMUdzmsF1Tk1FOR7k92kMulRN31LkiWV45F3eAAvNwCS8acu9endK', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (43, 107, '18783205676', '李泳龙', '00', '', '18783205676', '0', '', '$2a$10$LHQQe3UHQgaJDCnPl.gujuBKgRhrMN88kPKRxev2HSvOrV2IDRAfG', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (44, 108, '13402863790', '何   杰', '00', '', '13402863790', '0', '', '$2a$10$XZhKTnoYh.zS/TczIVjJyOVMvwjQ.fiH3QtTpB9M2OaHnhpIiOYWS', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (45, 108, '18224091291', '杨玉婧', '00', '', '18224091291', '1', '', '$2a$10$goGcN9K63wIO7t8Rkw95kuMb1twHzRU51Dk6q31/.Hejl2Aro0kVq', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (46, 108, '15196615885', '余思翰', '00', '', '15196615885', '1', '', '$2a$10$IjogDx43u3xmI2TigAo6CugCKh.AAmwOSf1nKBCWlJ/cEhgpX.H3e', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (47, 108, '17716873691', '阮梦妍', '00', '', '17716873691', '1', '', '$2a$10$XXlN3NzrRMBmMudrV3ZgOOtEq.RML/KrrVhN/uh.rpP7chAqy8QTe', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (48, 108, '15881196342', '赵   芩', '00', '', '15881196342', '1', '', '$2a$10$x2pMljHso1uFHnjDpFu0/OPGrU1ITvl7hnv/bwFFQVUIH/mQ39k2G', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (49, 108, '18502889383', '王荣华', '00', '', '18502889383', '0', '', '$2a$10$G7uXmOzRgagbI2jske8meuu8p0QgvTvMxLDzV0gQWHVaKJTsW6e3i', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (50, 108, '19982093641', '屈亚星', '00', '', '19982093641', '1', '', '$2a$10$gklMWtGS2E8tdWakJpNk9OyEv2g/2MGuQupEH0Q7zCpZI9XJPMxyC', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (51, 109, '13880509805', '吴   凯', '00', '', '13880509805', '0', '', '$2a$10$AN5g8asAyLLW9.POKvkh8.WPCKqzf4Ze71ltLA.wIbEqIH3fQSj0q', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (52, 109, '13981911565', '李   旭', '00', '', '13981911565', '0', '', '$2a$10$j4GUGW8LwJVW5kS98xis3.PYbeMsqjJwiJBnmj1lYpS04hqp7IvMi', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (53, 109, '13708077449', '马如坤', '00', '', '13708077449', '0', '', '$2a$10$SO9HTWCXPMBbHiMUs73YdON7RYGfi0LbB/Tfyq5e7BZaxSbJvTB3S', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (54, 109, '13684088875', '张   进', '00', '', '13684088875', '0', '', '$2a$10$TMJoxh5FamkqFR7crz.eh.1/jwx9JdyAm9SAE/wzZdwgzfqjljvGC', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (55, 109, '13550225550', '冉洪芳', '00', '', '13550225550', '1', '', '$2a$10$N0iuZU3JhPqLBogqtMbmeuL1aGb/D3E0Yh3UUoJX6yV.iaVT1WBhq', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (56, 109, '13880738350', '周文婷', '00', '', '13880738350', '1', '', '$2a$10$Z8hiF47EMxhCXq9I/xbLbuJloSnoARKeiRgodgBcer7lq1VsYE3fC', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (57, 109, '13558636992', '谭   君', '00', '', '13558636992', '1', '', '$2a$10$uBsL6WPQpYCbT0oddsoll.VrLlMDrRWU2my.VdnNovu9c.thOXR1e', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (58, 109, '13658078979', '王晶丽', '00', '', '13658078979', '1', '', '$2a$10$PBNCy8SQPudxBTigEEXVAuIot2PoUDMz6KV1u8TeXBvXiS0CAUMtW', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (59, 109, '13488986700', '罗业华', '00', '', '13488986700', '0', '', '$2a$10$8np5PzaPEkMQwRYUzSnUX.pDQSRdbpFXyzhtYvBj11OzTaNmGAEtG', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (60, 109, '13540297596', '郎悟灵', '00', '', '13540297596', '1', '', '$2a$10$BU3usTExEEbFa7VGIbnOgeAJ3CsJXPkzV6ZTH2xRtu70Es76RP5j.', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (61, 109, '18030862435', '黄俊峰', '00', '', '18030862435', '0', '', '$2a$10$gBqKUDSxjc4mHUp6Pcrp8evF1BVhgkpq8cm65iqWtHkkDP1wk/Jaa', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (62, 110, '15881027005', '赵   洪', '00', '', '15881027005', '0', '', '$2a$10$HbyEXT7JR0HMv/rqi9YuQOKCyDxZg/uYgayoSOcE2.tDSVNS0OBpW', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (63, 110, '18782047395', '雷情情', '00', '', '18782047395', '1', '', '$2a$10$DLeq2ePfvTS9cAarUu87LuM8d1nwJR5t/OBI3kc5nT858nIo0vpR2', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (64, 110, '13668275672', '刘向东', '00', '', '13668275672', '0', '', '$2a$10$GUkGxa.u4jsBVE5mAXVTcetM0t6JIxMPUthi6v5IitkVSZUlpzf5.', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (65, 110, '13880738396', '徐志勇', '00', '', '13880738396', '0', '', '$2a$10$toSkneflSQedWXrjbim6lut03gEx1HlV4FV1UFYocdtDpEhpbbLam', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (66, 110, '15828108217', '李   敏', '00', '', '15828108217', '1', '', '$2a$10$c8ADHg87uPh0KaTXl.hWm.5z4hVDRtFmTprgfAJ1y.yVj27mEvV8i', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (67, 110, '13689063294', '何   玲', '00', '', '13689063294', '1', '', '$2a$10$v1/ZnLyGAQwuQ7fUjy/kdeklmPo7e3uR/ogj5KmvjIPEQF7mqM/BS', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (68, 110, '15982266763', '谭天宇', '00', '', '15982266763', '0', '', '$2a$10$QNa18og32fQ979WGRWGFTOLgHszwXzvE.a9dSnuqMqQ4hABt5MBRa', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (69, 110, '18384964273', '李丽昕', '00', '', '18384964273', '1', '', '$2a$10$f7M7gFzNtCxjBCDZjXlvz.ROHw7vedqYtpX1BRLmT9X/5OouCXna2', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (70, 110, '15108259951', '陈   波', '00', '', '15108259951', '0', '', '$2a$10$nkbLOjwcHqge.kwX4bTSWOxX6owLTazGVVrthxxPiun9zLP8NpYTW', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (71, 110, '18483229925', '张   敏', '00', '', '18483229925', '1', '', '$2a$10$UodO6Pu05eUct21vfnuQIOIwHhuEw3xkmZPEFjaeP378YoiQ/86Ee', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (72, 110, '15308209119', '李   磊', '00', '', '15308209119', '0', '', '$2a$10$DYNX/J5XG6CCniWthrA3KOau0kWEw8gtMSnS7dhtofuCpZLQfyRsG', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (73, 110, '18190687602', '杨为康', '00', '', '18190687602', '0', '', '$2a$10$Vzo2gOmvHdI6TZxZCO2iTePU8fa9oVN6xPmyT2ZapQ2sZEJRM.tWa', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (74, 110, '15202868564', '夏志斌', '00', '', '15202868564', '0', '', '$2a$10$ucCDdz5DYNZy64aKKSxH/.Lib./7T5rLGECIWXzwBLalCQk0X1fka', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (75, 110, '18048613219', '刘轩庭', '00', '', '18048613219', '0', '', '$2a$10$.pSSK43SDZGc3tt1sjZREe/d0hCAbHpmUKvyFzJ1vtctvSZpdf.ka', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (76, 110, '18482156612', '廖友福', '00', '', '18482156612', '0', '', '$2a$10$47nqvaqoPpAbcR9wH.ar9.nBCbKshOpTP0HwgBxsFWt3wqSaW/U0y', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (77, 110, '13880417112', '潘林海', '00', '', '13880417112', '0', '', '$2a$10$z1iuKFb6q9SSiXoELcrfjuYWLnAbPorD42T.5nCEmLUXwL0/Ahe8m', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (78, 110, '13518119939', '邓锡全', '00', '', '13518119939', '0', '', '$2a$10$auJq1XFdaj.2.WXKS98mxOWcprpL3LGl5h3Fd1sBwAoUfh1c6zlrK', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (79, 110, '15208122776', '张   杰', '00', '', '15208122776', '0', '', '$2a$10$HcC7iiq4GR1Ca0JRrJntOemcBW3vO.tt9/EUbmvQJ9M.QIs1j6IJC', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (80, 110, '17345094889', '廖   双', '00', '', '17345094889', '0', '', '$2a$10$AA3hI9GxRBB3XD9N/NthD.nqYf487wG3BvJQgYsSTublKos1Gy1Km', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (81, 110, '15520996706', '廖吉兴', '00', '', '15520996706', '0', '', '$2a$10$/KNuVYgY/iKADZZg.iykyuJK/rrgi/CpbZy.ZFv3NKm4MrpqBnCFu', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (82, 110, '15692823805', '王海宾', '00', '', '15692823805', '0', '', '$2a$10$OF1jB2LgFMeaakI6NTPqx.nTTe4bKzZeaP9dYccOk0v0rdCzja7Jy', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (83, 111, '13540773353', '杨   振', '00', '', '13540773353', '0', '', '$2a$10$m8MnVkkjv9DT7GRaVDfG9e0lQM79NJPBwFQL3eckGh32qylKlNeky', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (84, 111, '18380220140', '甘雨婷', '00', '', '18380220140', '1', '', '$2a$10$HXgw5OtU9uUCiKbSAPG0xe5PwGiZWlCIlJtltgXdtCYIZxIcKw01S', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (85, 111, '13608005983', '周   强', '00', '', '13608005983', '0', '', '$2a$10$jIiDO3ighwg51nlJe4WbZet365ysf61KTuqrDNsF9YD90fHAMf9cy', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (86, 111, '13540422960', '邹   霞', '00', '', '13540422960', '1', '', '$2a$10$JGmiiO3vjhEF5e2BXubE1uE/DRzpcmK3SMBZo/EDExsd8L9TWqEHm', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (87, 111, '13488985627', '罗声燕', '00', '', '13488985627', '1', '', '$2a$10$.lFR.S8c/i3550O88zhk4OIyeYF2vmulknGqBvE/hi8b9id1RLNry', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (88, 111, '18227609102', '王   琴', '00', '', '18227609102', '1', '', '$2a$10$hW41I3wMpnM.GiPO85jv3eyr6uJglfpj2SV/fU9etfXuBjHgIIveO', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (89, 111, '15281034798', '李   静', '00', '', '15281034798', '1', '', '$2a$10$BIV.X9sgXwCLmnx0MjvbN.xnJ0d9mSv7Fe1HsB.d5UvqhYBux4aRK', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (90, 111, '18380143305', '刘   垚', '00', '', '18380143305', '1', '', '$2a$10$9pXNh3pit.p.3lCv.1vIAeqm594O0y2ycUVTK5aXqbf1.DD9ckHr6', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (91, 111, '15208298451', '李   杨', '00', '', '15208298451', '0', '', '$2a$10$K25fAdfUGilTZz9BHlKBnezcMkD/Pv.uJKM1H0/jn.cOOas5jDVea', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (92, 111, '18990913384', '朱   姝', '00', '', '18990913384', '1', '', '$2a$10$GXcpkSxBeuM1tj66W6M50.YPQKMOccRTD64wikP5LuRW0PMhJ2Z5q', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (93, 111, '18483229950', '唐   浩', '00', '', '18483229950', '0', '', '$2a$10$B..WW48a/JzGIgxdKoQEuu70YDGVmqJf/PV/WzcWjhatTZMA9Ch..', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (94, 111, '15108355309', '张   韦', '00', '', '15108355309', '0', '', '$2a$10$2aepTeKqlbUhb1x6i0K88OxLlZohvIf5JZ2xhgZO8It5MagkvLHHC', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (95, 111, '18108260500', '黄建春', '00', '', '18108260500', '0', '', '$2a$10$sfPuHSWY3AytrF7.o/cMAeXwb.GU1/wk4VJw4FLKgEnLNKlMdIRee', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (96, 111, '13881755761', '廖绍毅', '00', '', '13881755761', '0', '', '$2a$10$g9/NOZbNS6eIcqnEg6Z2geNyQIMNJtTJrahTvIYeDis68GaQ.McJG', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (97, 111, '15700353317', '杨   晶', '00', '', '15700353317', '0', '', '$2a$10$Efj2FINLArOIOgEKa3vqp.k0gpwmJKlWWlXwTrQmSIO2qsVlIWZAa', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (98, 111, '13618069959', '蒋剑虹', '00', '', '13618069959', '0', '', '$2a$10$5osgmB9ZInuTYvyMUedKqe2aDJM91i/KjOxGWWCZb9WO/45U7Zok.', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (99, 111, '13882487125', '赵明焱', '00', '', '13882487125', '0', '', '$2a$10$zs4QH/xd0JDuYgrftHUhRedB5SWCE.d7pdTxhUmdo/OYVxx2fSFWq', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (100, 111, '18228226661', '董旭鹏', '00', '', '18228226661', '0', '', '$2a$10$yaBpFaISskiafcOa/k28VeSQSMiYhCxbtmMoXN/fruESTkMs4RwA6', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (101, 111, '15775308748', '邓汶滨', '00', '', '15775308748', '0', '', '$2a$10$5L36DYl/Q.wmGKsolG/x0u4vnK78sVY59Qjx6fQA3z9n4dl62ykM.', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (102, 111, '19949408104', '罗   毅', '00', '', '19949408104', '0', '', '$2a$10$2QEEZ1VZ0Me6Ndaoon78Z.V7mBAyLIZKf7EokR/zILsd837A7ITgq', '0', '0', '', null, null, '2024-01-04 17:22:48', '', null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (103, 112, '13688460154', '周   全', '00', '', '13688460154', '0', '', '$2a$10$TQMgM2lTRkeTB4YY5IHQ0.xvCGZlnd774UdWe.OPGElTkRuLAsEz6', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (104, 112, '13688404696', '柏金川', '00', '', '13688404696', '0', '', '$2a$10$4ih05H.SB537jI2sHx756.hQvWBbm.4ViXs7HFKndjDQDCyvYz1rO', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (105, 112, '15802829286', '向艳雄', '00', '', '15802829286', '0', '', '$2a$10$FQo1zf1ss2OZw4eIlzzxwOyPV0FkkLDN0ZBxqRSIijNpUCCSxBjQy', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (106, 112, '13594658239', '黄安堂', '00', '', '13594658239', '0', '', '$2a$10$uSefDVQx.kottALOIZptjO0RnZhvITS4QTnXjSBJddqYfOftdZ8Pa', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (107, 112, '13408566079', '李学勇', '00', '', '13408566079', '0', '', '$2a$10$8ru4dmjHBh21h8C3FTpdMeqsG4RHVyvqmqUFRFCDCUok2uH2ZLjiy', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (108, 112, '15881283512', '陈俊恺', '00', '', '15881283512', '0', '', '$2a$10$eqX3G0LjlptoBsMefxIjXuzSEaq5opPJjzqoitrp4Dhun3u1o1F1i', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (109, 112, '15883351306', '彭永红', '00', '', '15883351306', '0', '', '$2a$10$Tlq6UDINB73aeR8MCW6emOO7MHLRUGkTZ0ud/oNvTrJllwwDpxhGe', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (110, 112, '18281010079', '邓   静', '00', '', '18281010079', '0', '', '$2a$10$pstdOImPwTHv54sONZEyBObA1RySMTJx2rx5btFUq6WF3qkkeP2Y6', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (111, 112, '18328739381', '刘庆波', '00', '', '18328739381', '0', '', '$2a$10$p72rrc68EO/XkCYDVVTNDurHcg4z64VgyedcadnOiX7RWV2GU7pv.', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (112, 112, '18205207306', '高   强', '00', '', '18205207306', '0', '', '$2a$10$p9WM4wlg34eq7yb9GAe.a.yvZhqsUBVQ.DIFIrBWZ5ufrUsu5oIKm', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (113, 112, '18380411075', '韩兴国', '00', '', '18380411075', '0', '', '$2a$10$0RNiRPmnuFMvCbRsSAQ4COgX0GRbi304ZpcNuV/gzAoZFYwv1fNYS', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (114, 112, '13693480782', '何   安', '00', '', '13693480782', '0', '', '$2a$10$vPcVlPiTH2nOO48/JTeXt.FpFoc9V407XxcCUmbt23Fe3pL5AvqYK', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (115, 113, '18628072166', '李春生', '00', '', '18628072166', '0', '', '$2a$10$Nojkqmf0J0e2ZG/7H/RNAOLQvtoCgOB.zqf52oCXnbW7XlN6VzaOe', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (116, 113, '13980688458', '段文祥', '00', '', '13980688458', '0', '', '$2a$10$4ETMsgQR7HcIjqmE3SXATOxud3L/tpPiYqt0GGRHsIB55WM4rR9Ry', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (117, 113, '18980006770', '张   伟', '00', '', '18980006770', '0', '', '$2a$10$dtTx73vRXEnbuwbyt.Hm4uhDLRI07BOwgRMMx1/tZBBy9CFTb8Mw6', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (118, 113, '15298033499', '万   明', '00', '', '15298033499', '0', '', '$2a$10$D9KhWl1cXJd7X8ejB8cZmODrpw.7CY0QROlXYc20zy/tyhGAbFZcW', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (119, 113, '18345595350', '王雨地', '00', '', '18345595350', '0', '', '$2a$10$pwU00C244h.JM52gYAwXDemz8GD6G8QQL81ZIHHswR6owx3JJQzf2', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (120, 113, '13881710080', '陈   兰', '00', '', '13881710080', '1', '', '$2a$10$sXVsn5kxi5rNd5mYJW.MrOKfY1YY/eFYYUNAm6f8A9Ak9JbF2Js0y', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (121, 113, '18582552495', '张   可', '00', '', '18582552495', '0', '', '$2a$10$..LijGqYettSPi41oAdLnehfukhiYKPpI9t1EKaYhrTyuW/y.v.By', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (122, 114, '13551823637', '李   锋', '00', '', '13551823637', '0', '', '$2a$10$/T1kLMSSFMAmoy4QhkTzFO1vVm8/csHuuaeAKsjeEx/w1d3SsA2pi', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (123, 114, '13881397406', '张元锋', '00', '', '13881397406', '0', '', '$2a$10$3L/5ASJal42wccw7BhyIaOcedcj6IOadjnUGymzWH/kbYYQmA/K3y', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (124, 114, '18602865330', '钱俊锦', '00', '', '18602865330', '0', '', '$2a$10$YuF2Yk6rCdCIu0c5Q6Uw4eBdh3vcTmbCpmETgd.FI.RVUVL.uTLEq', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (125, 114, '17311677347', '陈   伟', '00', '', '17311677347', '0', '', '$2a$10$fbrbmyWNFA7aiCbOtCqaDONw7qDgdS4UZDS95BUOHJ88eUzVtr3/S', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (126, 114, '13628057328', '薛   帅', '00', '', '13628057328', '0', '', '$2a$10$ND.pJthbdY1tY8LHYtJkpeADmaTDJNvwPClaERSAyKIcLd4xT5uyq', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (127, 114, '18482173451', '冉凉南', '00', '', '18482173451', '0', '', '$2a$10$IyIeQtlKtZTNpidzX4R.7OOWt21XkMBiHZn92F/f8oT94QfMUKoA6', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (128, 114, '18382319155', '谢承东', '00', '', '18382319155', '0', '', '$2a$10$AkWugwBKCG7oKIKPIn9mBOaFtuCtTw3cJvz78ryEMUTTjfG/fDYgy', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (129, 114, '18227480379', '周   炎', '00', '', '18227480379', '0', '', '$2a$10$5e7lOXqGekSSu.rKKMQJYuLJc68RZllH2ebGFEr/He6cc2zsQJPzm', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (130, 114, '18140430240', '胡   庆', '00', '', '18140430240', '0', '', '$2a$10$IckBbWNu8BS6JkdITuvMzu7G/Ztl.d.gbp1xwQqpgYDUEYEaxFUkS', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (131, 114, '18780029464', '何   行', '00', '', '18780029464', '0', '', '$2a$10$0BpGvlJOqHQyM//wJh3lAO/7e/s.dys5iVCGu0K/qcjsLpgveK4ou', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (132, 103, '18283500919', '杨良轩', '00', '', '18283500919', '0', '', '$2a$10$vUYbhAPQRZuj8S5cjvC5XODjTswaxbWr049ICezchhb4ueoNQ4S6i', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (133, 103, '13880159142', '周建伟', '00', '', '13880159142', '0', '', '$2a$10$vY871WQd/F9BGNg1Ki2.VOYsT704ttmif5b3U1Aaj392CydaVTTfm', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (134, 103, '13980809722', '罗友权', '00', '', '13980809722', '0', '', '$2a$10$/cL8xD1pFmFxLyehpr2x1e3n/8KqKG6lWaXdjyHyaZo37oCP4wfem', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (135, 103, '15228916534', '凌   涛', '00', '', '15228916534', '0', '', '$2a$10$BdjU17zPn5JZpcyOBBK3X.GiQOdZfuRVmiljOJMde4/EJM67Zp7/C', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (136, 103, '15928517280', '雷光泽', '00', '', '15928517280', '0', '', '$2a$10$soo68IbKDhCT0mhj.j0Nou2rsgVxLU78BsowMo7ZorasQj9FPf2OG', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (137, 103, '15828156243', '廖   勇', '00', '', '15828156243', '0', '', '$2a$10$9QO6qXNSAiAtWFCXbvEeu.pHoBLHZig5ra.y2ZNRyRDxL0W4WU2Q2', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (138, 103, '14726050305', '康科伟', '00', '', '14726050305', '0', '', '$2a$10$04.7zNYdTwXzlQ8J0SYNaOZMc.iarm2gBeD37na6.aAtuBzfnpnUO', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (139, 103, '18111675896', '熊艳华', '00', '', '18111675896', '0', '', '$2a$10$uLfMqz3YfEuAO8TI0XOzE.Xn0FZA7U6zrfss6Xp.anF4xUZNXT37y', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (140, 103, '18982085285', '赵永来', '00', '', '18982085285', '0', '', '$2a$10$TzKjV2T1FJ7YubxeIZZnmuLBsdppYlHoxruXCh0aBhHyV/yLGaiai', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (141, 115, '15982167611', '刘   洋', '00', '', '15982167611', '0', '', '$2a$10$qxB0MTpLA7WzUhBpQlrC5u.7JymKt2bwAJ9gupwWQeKcANtov0qn.', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (142, 115, '17345090038', '郑   鹏', '00', '', '17345090038', '0', '', '$2a$10$meTOhyDbWqzhrzCFDGM3hu.cOFwinewDE1Jp3YYR/ThYBvOssce7G', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (143, 115, '17612894797', '黄   强', '00', '', '17612894797', '0', '', '$2a$10$JyofvRfiRj5Ug2G4ux00eOtMvQSOKu.tjo0.Juey2xMZSsAggVE76', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (144, 116, '13980977233', '李   禺', '00', '', '13980977233', '0', '', '$2a$10$AiciBrz84EwU3G3KxW9bCOZXgxraa74RRzAvyetSEjC30Zvq2ooH2', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (145, 116, '18602830814', '黄梅琳', '00', '', '18602830814', '1', '', '$2a$10$Ij6SqoLMDrpLBJ87rKqIh.8JDRNMROQQyHQSZV5wsUn7ybJ53ip86', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (146, 116, '13488982667', '尹   超', '00', '', '13488982667', '0', '', '$2a$10$F.REC7OQ2uNCFeUOpopqaeSsDn9MR/a01G4TTG.uaCgq2OukjBXrO', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (147, 116, '15881108097', '程   昊', '00', '', '15881108097', '0', '', '$2a$10$y1Z2H5Wp4yhdnmHcNO7U6u9108qE/uxqQ7OVumAtVLlgDbj/ZWo/.', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (148, 116, '15928663470', '丁   亮', '00', '', '15928663470', '0', '', '$2a$10$WYBOgIm.Y.LNSEKs3VPaX.1JpD.VLodHuug5wOeX636vln31SHII2', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (149, 117, '13880644169', '林方迁', '00', '', '13880644169', '0', '', '$2a$10$VPrToUrklp3J3NtnHAy7VulN9Eck4eTuII4xmXh.JKOue9BN91Tq.', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);
insert into sys_user values (150, 117, '18140055216', '杨   柳', '00', '', '18140055216', '1', '', '$2a$10$K1WECO/2G5tAKCr3h16CzeypD2CSVjq1MWdk1FLjhnAKD2SwanrT6', '0', '0', '', null, null, '2024-01-04 17:22:48', null, null, null, null, null, null, null, null, null, null, null);


-- ----------------------------
-- 3、岗位信息表
-- ----------------------------
drop table if exists sys_post;
create table sys_post
(
  post_id       bigint(20)      not null auto_increment    comment '岗位ID',
  post_code     varchar(64)     not null                   comment '岗位编码',
  post_name     varchar(50)     not null                   comment '岗位名称',
  post_sort     int(4)          not null                   comment '显示顺序',
  status        char(1)         not null                   comment '状态（0正常 1停用）',
  create_by     varchar(64)     default ''                 comment '创建者',
  create_time   datetime                                   comment '创建时间',
  update_by     varchar(64)     default ''			       comment '更新者',
  update_time   datetime                                   comment '更新时间',
  remark        varchar(500)    default null               comment '备注',
  primary key (post_id)
) engine=innodb comment = '岗位信息表';

-- ----------------------------
-- 初始化-岗位信息表数据
-- ----------------------------
insert into sys_post values (1, '1', '董事长', 1, '0', 'admin', '2024-01-04 14:21:52', null, null, null);
insert into sys_post values (2, '2', '总经理', 2, '0', 'admin', '2024-01-04 14:22:52', null, null, null);
insert into sys_post values (3, '3', '董事', 3, '0', 'admin', '2024-01-04 14:32:11', null, null, null);
insert into sys_post values (4, '4', '总支书记', 4, '0', 'admin', '2024-01-04 14:34:43', null, null, null);
insert into sys_post values (5, '5', '高级顾问', 5, '0', 'admin', '2024-01-04 14:35:34', null, null, null);
insert into sys_post values (6, '6', '副总经理', 6, '0', 'admin', '2024-01-04 14:35:48', null, null, null);
insert into sys_post values (7, '7', '秘书', 7, '0', 'admin', '2024-01-04 14:36:08', null, null, null);
insert into sys_post values (8, '8', '总支干事', 8, '0', 'admin', '2024-01-04 14:37:29', null, null, null);
insert into sys_post values (9, '9', '总工程师', 9, '0', 'admin', '2024-01-04 14:37:43', null, null, null);
insert into sys_post values (10, '10', '总经理助理', 10, '0', 'admin', '2024-01-04 14:38:00', null, null, null);
insert into sys_post values (11, '11', '副总工程师', 11, '0', 'admin', '2024-01-04 14:42:07', null, null, null);
insert into sys_post values (12, '12', '主任', 12, '0', 'admin', '2024-01-04 14:39:20', null, null, null);
insert into sys_post values (13, '13', '副主任', 13, '0', 'admin', '2024-01-04 14:39:34', null, null, null);
insert into sys_post values (14, '14', '专总', 14, '0', 'admin', '2024-01-04 14:40:44', null, null, null);
insert into sys_post values (15, '15', '经理', 15, '0', 'admin', '2024-01-04 14:48:57', null, null, null);
insert into sys_post values (16, '16', '副经理', 16, '0', 'admin', '2024-01-04 16:50:16', '', null, null);
insert into sys_post values (17, '17', '项目主任', 17, '0', 'admin', '2024-01-04 16:49:08', '', null, null);
insert into sys_post values (18, '18', '项目副主任', 18, '0', 'admin', '2024-01-04 16:49:58', '', null, null);
insert into sys_post values (19, '19', '专职安全员', 19, '0', 'admin', '2024-01-04 15:32:52', '', null, null);
insert into sys_post values (20, '20', '工会干事', 20, '0', 'admin', '2024-01-04 14:49:48', null, null, null);
insert into sys_post values (21, '21', '业务主管', 21, '0', 'admin', '2024-01-04 14:50:20', null, null, null);
insert into sys_post values (22, '22', '业务助理', 22, '0', 'admin', '2024-01-04 14:51:41', null, null, null);
insert into sys_post values (23, '23', '文秘、办事员', 23, '0', 'admin', '2024-01-04 14:52:29', null, null, null);
insert into sys_post values (24, '24', '会计', 24, '0', 'admin', '2024-01-04 14:53:13', null, null, null);
insert into sys_post values (25, '25', '出纳', 25, '0', 'admin', '2024-01-04 14:53:27', null, null, null);
insert into sys_post values (26, '26', '员工', 26, '0', 'admin', '2024-01-04 14:53:34', null, null, null);
insert into sys_post values (27, '27', '驾驶员', 27, '0', 'admin', '2024-01-04 14:53:50', null, null, null);


-- ----------------------------
-- 4、角色信息表
-- ----------------------------
drop table if exists sys_role;
create table sys_role (
  role_id              bigint(20)      not null auto_increment    comment '角色ID',
  role_name            varchar(30)     not null                   comment '角色名称',
  role_key             varchar(100)    not null                   comment '角色权限字符串',
  role_sort            int(4)          not null                   comment '显示顺序',
  data_scope           char(1)         default '1'                comment '数据范围（1：全部数据权限 2：自定数据权限 3：本部门数据权限 4：本部门及以下数据权限）',
  menu_check_strictly  tinyint(1)      default 1                  comment '菜单树选择项是否关联显示',
  dept_check_strictly  tinyint(1)      default 1                  comment '部门树选择项是否关联显示',
  status               char(1)         not null                   comment '角色状态（0正常 1停用）',
  del_flag             char(1)         default '0'                comment '删除标志（0代表存在 2代表删除）',
  create_by            varchar(64)     default ''                 comment '创建者',
  create_time          datetime                                   comment '创建时间',
  update_by            varchar(64)     default ''                 comment '更新者',
  update_time          datetime                                   comment '更新时间',
  remark               varchar(500)    default null               comment '备注',
  primary key (role_id)
) engine=innodb auto_increment=100 comment = '角色信息表';

-- ----------------------------
-- 初始化-角色信息表数据
-- ----------------------------
insert into sys_role values('1', '超级管理员',  'admin',  1, 1, 1, 1, '0', '0', 'admin', sysdate(), '', null, '超级管理员');
insert into sys_role values('2', '普通角色',    'common', 2, 2, 1, 1, '0', '0', 'admin', sysdate(), '', null, '普通角色');


-- ----------------------------
-- 5、菜单权限表
-- ----------------------------
drop table if exists sys_menu;
create table sys_menu (
  menu_id           bigint(20)      not null auto_increment    comment '菜单ID',
  menu_name         varchar(50)     not null                   comment '菜单名称',
  parent_id         bigint(20)      default 0                  comment '父菜单ID',
  order_num         int(4)          default 0                  comment '显示顺序',
  path              varchar(200)    default ''                 comment '路由地址',
  component         varchar(255)    default null               comment '组件路径',
  query             varchar(255)    default null               comment '路由参数',
  is_frame          int(1)          default 1                  comment '是否为外链（0是 1否）',
  is_cache          int(1)          default 0                  comment '是否缓存（0缓存 1不缓存）',
  menu_type         char(1)         default ''                 comment '菜单类型（M目录 C菜单 F按钮）',
  visible           char(1)         default 0                  comment '菜单状态（0显示 1隐藏）',
  status            char(1)         default 0                  comment '菜单状态（0正常 1停用）',
  perms             varchar(100)    default null               comment '权限标识',
  icon              varchar(100)    default '#'                comment '菜单图标',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time       datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间',
  remark            varchar(500)    default ''                 comment '备注',
  primary key (menu_id)
) engine=innodb auto_increment=2000 comment = '菜单权限表';

-- ----------------------------
-- 初始化-菜单信息表数据
-- ----------------------------
-- 一级菜单
insert into sys_menu values('1', '系统管理', '0', '1', 'system',           null, '', 1, 0, 'M', '0', '0', '', 'system',   'admin', sysdate(), '', null, '系统管理目录');
insert into sys_menu values('2', '系统监控', '0', '2', 'monitor',          null, '', 1, 0, 'M', '0', '0', '', 'monitor',  'admin', sysdate(), '', null, '系统监控目录');
insert into sys_menu values('3', '系统工具', '0', '3', 'tool',             null, '', 1, 0, 'M', '0', '0', '', 'tool',     'admin', sysdate(), '', null, '系统工具目录');
insert into sys_menu values('4', '车辆管理', '0', '4', 'car',    	  'oa/car/index',        	  '', 1, 0, 'C', '0', '0', 'oa:car:list',       	  'car',       	   'admin', sysdate(), '', null, '车辆管理菜单');
insert into sys_menu values('5', '项目管理', '0', '5', 'project',	  'oa/project/index',         '', 1, 0, 'C', '0', '0', 'oa:project:list',         'project',       'admin', sysdate(), '', null, '项目管理菜单');
-- 二级菜单
insert into sys_menu values('100',  '用户管理', '1',   '1', 'user',       'system/user/index',        '', 1, 0, 'C', '0', '0', 'system:user:list',        'user',          'admin', sysdate(), '', null, '用户管理菜单');
insert into sys_menu values('101',  '角色管理', '1',   '2', 'role',       'system/role/index',        '', 1, 0, 'C', '0', '0', 'system:role:list',        'peoples',       'admin', sysdate(), '', null, '角色管理菜单');
insert into sys_menu values('102',  '菜单管理', '1',   '3', 'menu',       'system/menu/index',        '', 1, 0, 'C', '0', '0', 'system:menu:list',        'tree-table',    'admin', sysdate(), '', null, '菜单管理菜单');
insert into sys_menu values('103',  '部门管理', '1',   '4', 'dept',       'system/dept/index',        '', 1, 0, 'C', '0', '0', 'system:dept:list',        'tree',          'admin', sysdate(), '', null, '部门管理菜单');
insert into sys_menu values('104',  '岗位管理', '1',   '5', 'post',       'system/post/index',        '', 1, 0, 'C', '0', '0', 'system:post:list',        'post',          'admin', sysdate(), '', null, '岗位管理菜单');
insert into sys_menu values('105',  '字典管理', '1',   '6', 'dict',       'system/dict/index',        '', 1, 0, 'C', '0', '0', 'system:dict:list',        'dict',          'admin', sysdate(), '', null, '字典管理菜单');
insert into sys_menu values('106',  '参数设置', '1',   '7', 'config',     'system/config/index',      '', 1, 0, 'C', '0', '0', 'system:config:list',      'edit',          'admin', sysdate(), '', null, '参数设置菜单');
insert into sys_menu values('107',  '通知公告', '1',   '8', 'notice',     'system/notice/index',      '', 1, 0, 'C', '0', '0', 'system:notice:list',      'message',       'admin', sysdate(), '', null, '通知公告菜单');
insert into sys_menu values('108',  '日志管理', '1',   '9', 'log',        '',                         '', 1, 0, 'M', '0', '0', '',                        'log',           'admin', sysdate(), '', null, '日志管理菜单');
insert into sys_menu values('109',  '在线用户', '2',   '1', 'online',     'monitor/online/index',     '', 1, 0, 'C', '0', '0', 'monitor:online:list',     'online',        'admin', sysdate(), '', null, '在线用户菜单');
insert into sys_menu values('110',  '定时任务', '2',   '2', 'job',        'monitor/job/index',        '', 1, 0, 'C', '0', '0', 'monitor:job:list',        'job',           'admin', sysdate(), '', null, '定时任务菜单');
insert into sys_menu values('111',  '数据监控', '2',   '3', 'druid',      'monitor/druid/index',      '', 1, 0, 'C', '0', '0', 'monitor:druid:list',      'druid',         'admin', sysdate(), '', null, '数据监控菜单');
insert into sys_menu values('112',  '服务监控', '2',   '4', 'server',     'monitor/server/index',     '', 1, 0, 'C', '0', '0', 'monitor:server:list',     'server',        'admin', sysdate(), '', null, '服务监控菜单');
insert into sys_menu values('113',  '缓存监控', '2',   '5', 'cache',      'monitor/cache/index',      '', 1, 0, 'C', '0', '0', 'monitor:cache:list',      'redis',         'admin', sysdate(), '', null, '缓存监控菜单');
insert into sys_menu values('114',  '缓存列表', '2',   '6', 'cacheList',  'monitor/cache/list',       '', 1, 0, 'C', '0', '0', 'monitor:cache:list',      'redis-list',    'admin', sysdate(), '', null, '缓存列表菜单');
insert into sys_menu values('115',  '表单构建', '3',   '1', 'build',      'tool/build/index',         '', 1, 0, 'C', '0', '0', 'tool:build:list',         'build',         'admin', sysdate(), '', null, '表单构建菜单');
insert into sys_menu values('116',  '代码生成', '3',   '2', 'gen',        'tool/gen/index',           '', 1, 0, 'C', '0', '0', 'tool:gen:list',           'code',          'admin', sysdate(), '', null, '代码生成菜单');
insert into sys_menu values('117',  '系统接口', '3',   '3', 'swagger',    'tool/swagger/index',       '', 1, 0, 'C', '0', '0', 'tool:swagger:list',       'swagger',       'admin', sysdate(), '', null, '系统接口菜单');
-- 三级菜单
insert into sys_menu values('500',  '操作日志', '108', '1', 'operlog',    'monitor/operlog/index',    '', 1, 0, 'C', '0', '0', 'monitor:operlog:list',    'form',          'admin', sysdate(), '', null, '操作日志菜单');
insert into sys_menu values('501',  '登录日志', '108', '2', 'logininfor', 'monitor/logininfor/index', '', 1, 0, 'C', '0', '0', 'monitor:logininfor:list', 'logininfor',    'admin', sysdate(), '', null, '登录日志菜单');
-- 用户管理按钮
insert into sys_menu values('1000', '用户列表', '100', '0',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:list',          '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1001', '用户查询', '100', '1',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:query',          '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1002', '用户新增', '100', '2',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:add',            '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1003', '用户修改', '100', '3',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:edit',           '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1004', '用户删除', '100', '4',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:remove',         '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1005', '用户导出', '100', '5',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:export',         '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1006', '用户导入', '100', '6',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:import',         '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1007', '重置密码', '100', '7',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:resetPwd',       '#', 'admin', sysdate(), '', null, '');
-- 角色管理按钮
insert into sys_menu values('1008', '角色查询', '101', '1',  '', '', '', 1, 0, 'F', '0', '0', 'system:role:query',          '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1009', '角色新增', '101', '2',  '', '', '', 1, 0, 'F', '0', '0', 'system:role:add',            '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1010', '角色修改', '101', '3',  '', '', '', 1, 0, 'F', '0', '0', 'system:role:edit',           '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1011', '角色删除', '101', '4',  '', '', '', 1, 0, 'F', '0', '0', 'system:role:remove',         '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1012', '角色导出', '101', '5',  '', '', '', 1, 0, 'F', '0', '0', 'system:role:export',         '#', 'admin', sysdate(), '', null, '');
-- 菜单管理按钮
insert into sys_menu values('1013', '菜单查询', '102', '1',  '', '', '', 1, 0, 'F', '0', '0', 'system:menu:query',          '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1014', '菜单新增', '102', '2',  '', '', '', 1, 0, 'F', '0', '0', 'system:menu:add',            '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1015', '菜单修改', '102', '3',  '', '', '', 1, 0, 'F', '0', '0', 'system:menu:edit',           '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1016', '菜单删除', '102', '4',  '', '', '', 1, 0, 'F', '0', '0', 'system:menu:remove',         '#', 'admin', sysdate(), '', null, '');
-- 部门管理按钮
insert into sys_menu values('1017', '部门查询', '103', '1',  '', '', '', 1, 0, 'F', '0', '0', 'system:dept:query',          '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1018', '部门新增', '103', '2',  '', '', '', 1, 0, 'F', '0', '0', 'system:dept:add',            '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1019', '部门修改', '103', '3',  '', '', '', 1, 0, 'F', '0', '0', 'system:dept:edit',           '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1020', '部门删除', '103', '4',  '', '', '', 1, 0, 'F', '0', '0', 'system:dept:remove',         '#', 'admin', sysdate(), '', null, '');
-- 岗位管理按钮
insert into sys_menu values('1021', '岗位查询', '104', '1',  '', '', '', 1, 0, 'F', '0', '0', 'system:post:query',          '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1022', '岗位新增', '104', '2',  '', '', '', 1, 0, 'F', '0', '0', 'system:post:add',            '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1023', '岗位修改', '104', '3',  '', '', '', 1, 0, 'F', '0', '0', 'system:post:edit',           '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1024', '岗位删除', '104', '4',  '', '', '', 1, 0, 'F', '0', '0', 'system:post:remove',         '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1025', '岗位导出', '104', '5',  '', '', '', 1, 0, 'F', '0', '0', 'system:post:export',         '#', 'admin', sysdate(), '', null, '');
-- 字典管理按钮
insert into sys_menu values('1026', '字典查询', '105', '1', '#', '', '', 1, 0, 'F', '0', '0', 'system:dict:query',          '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1027', '字典新增', '105', '2', '#', '', '', 1, 0, 'F', '0', '0', 'system:dict:add',            '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1028', '字典修改', '105', '3', '#', '', '', 1, 0, 'F', '0', '0', 'system:dict:edit',           '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1029', '字典删除', '105', '4', '#', '', '', 1, 0, 'F', '0', '0', 'system:dict:remove',         '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1030', '字典导出', '105', '5', '#', '', '', 1, 0, 'F', '0', '0', 'system:dict:export',         '#', 'admin', sysdate(), '', null, '');
-- 参数设置按钮
insert into sys_menu values('1031', '参数查询', '106', '1', '#', '', '', 1, 0, 'F', '0', '0', 'system:config:query',        '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1032', '参数新增', '106', '2', '#', '', '', 1, 0, 'F', '0', '0', 'system:config:add',          '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1033', '参数修改', '106', '3', '#', '', '', 1, 0, 'F', '0', '0', 'system:config:edit',         '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1034', '参数删除', '106', '4', '#', '', '', 1, 0, 'F', '0', '0', 'system:config:remove',       '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1035', '参数导出', '106', '5', '#', '', '', 1, 0, 'F', '0', '0', 'system:config:export',       '#', 'admin', sysdate(), '', null, '');
-- 通知公告按钮
insert into sys_menu values('1036', '公告查询', '107', '1', '#', '', '', 1, 0, 'F', '0', '0', 'system:notice:query',        '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1037', '公告新增', '107', '2', '#', '', '', 1, 0, 'F', '0', '0', 'system:notice:add',          '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1038', '公告修改', '107', '3', '#', '', '', 1, 0, 'F', '0', '0', 'system:notice:edit',         '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1039', '公告删除', '107', '4', '#', '', '', 1, 0, 'F', '0', '0', 'system:notice:remove',       '#', 'admin', sysdate(), '', null, '');
-- 操作日志按钮
insert into sys_menu values('1040', '操作查询', '500', '1', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:operlog:query',      '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1041', '操作删除', '500', '2', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:operlog:remove',     '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1042', '日志导出', '500', '3', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:operlog:export',     '#', 'admin', sysdate(), '', null, '');
-- 登录日志按钮
insert into sys_menu values('1043', '登录查询', '501', '1', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:logininfor:query',   '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1044', '登录删除', '501', '2', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:logininfor:remove',  '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1045', '日志导出', '501', '3', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:logininfor:export',  '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1046', '账户解锁', '501', '4', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:logininfor:unlock',  '#', 'admin', sysdate(), '', null, '');
-- 在线用户按钮
insert into sys_menu values('1047', '在线查询', '109', '1', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:online:query',       '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1048', '批量强退', '109', '2', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:online:batchLogout', '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1049', '单条强退', '109', '3', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:online:forceLogout', '#', 'admin', sysdate(), '', null, '');
-- 定时任务按钮
insert into sys_menu values('1050', '任务查询', '110', '1', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:job:query',          '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1051', '任务新增', '110', '2', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:job:add',            '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1052', '任务修改', '110', '3', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:job:edit',           '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1053', '任务删除', '110', '4', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:job:remove',         '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1054', '状态修改', '110', '5', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:job:changeStatus',   '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1055', '任务导出', '110', '6', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:job:export',         '#', 'admin', sysdate(), '', null, '');
-- 代码生成按钮
insert into sys_menu values('1056', '生成查询', '116', '1', '#', '', '', 1, 0, 'F', '0', '0', 'tool:gen:query',             '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1057', '生成修改', '116', '2', '#', '', '', 1, 0, 'F', '0', '0', 'tool:gen:edit',              '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1058', '生成删除', '116', '3', '#', '', '', 1, 0, 'F', '0', '0', 'tool:gen:remove',            '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1059', '导入代码', '116', '4', '#', '', '', 1, 0, 'F', '0', '0', 'tool:gen:import',            '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1060', '预览代码', '116', '5', '#', '', '', 1, 0, 'F', '0', '0', 'tool:gen:preview',           '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1061', '生成代码', '116', '6', '#', '', '', 1, 0, 'F', '0', '0', 'tool:gen:code',              '#', 'admin', sysdate(), '', null, '');
-- 车辆管理按钮
insert into sys_menu values('1062', '车辆查询', '4', '1', '#', '', '', 1, 0, 'F', '0', '0', 'oa:car:query',				'#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1063', '车辆新增', '4', '2', '#', '', '', 1, 0, 'F', '0', '0', 'oa:car:add',					'#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1064', '车辆修改', '4', '3', '#', '', '', 1, 0, 'F', '0', '0', 'oa:car:edit',              	'#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1065', '车辆删除', '4', '4', '#', '', '', 1, 0, 'F', '0', '0', 'oa:car:remove',              '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1066', '车辆导出', '4', '5', '#', '', '', 1, 0, 'F', '0', '0', 'oa:car:export',              '#', 'admin', sysdate(), '', null, '');
-- 车辆管理按钮
insert into sys_menu values('1067', '项目查询', '5', '1', '#', '', '', 1, 0, 'F', '0', '0', 'oa:project:query',			'#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1068', '项目新增', '5', '2', '#', '', '', 1, 0, 'F', '0', '0', 'oa:project:add',				'#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1069', '项目修改', '5', '3', '#', '', '', 1, 0, 'F', '0', '0', 'oa:project:edit',            '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1070', '项目删除', '5', '4', '#', '', '', 1, 0, 'F', '0', '0', 'oa:project:remove',          '#', 'admin', sysdate(), '', null, '');
insert into sys_menu values('1071', '项目导出', '5', '5', '#', '', '', 1, 0, 'F', '0', '0', 'oa:project:export',          '#', 'admin', sysdate(), '', null, '');

-- ----------------------------
-- 6、用户和角色关联表  用户N-1角色
-- ----------------------------
drop table if exists sys_user_role;
create table sys_user_role (
  user_id   bigint(20) not null comment '用户ID',
  role_id   bigint(20) not null comment '角色ID',
  primary key(user_id, role_id)
) engine=innodb comment = '用户和角色关联表';

-- ----------------------------
-- 初始化-用户和角色关联表数据
-- ----------------------------
insert into sys_user_role values (1, 1);
insert into sys_user_role values (2, 2);
insert into sys_user_role values (3, 2);
insert into sys_user_role values (4, 2);
insert into sys_user_role values (5, 2);
insert into sys_user_role values (6, 2);
insert into sys_user_role values (7, 2);
insert into sys_user_role values (8, 2);
insert into sys_user_role values (9, 2);
insert into sys_user_role values (10, 2);
insert into sys_user_role values (11, 2);
insert into sys_user_role values (12, 2);
insert into sys_user_role values (13, 2);
insert into sys_user_role values (14, 2);
insert into sys_user_role values (15, 2);
insert into sys_user_role values (16, 2);
insert into sys_user_role values (17, 2);
insert into sys_user_role values (18, 2);
insert into sys_user_role values (19, 2);
insert into sys_user_role values (20, 2);
insert into sys_user_role values (21, 2);
insert into sys_user_role values (22, 2);
insert into sys_user_role values (23, 2);
insert into sys_user_role values (24, 2);
insert into sys_user_role values (25, 2);
insert into sys_user_role values (26, 2);
insert into sys_user_role values (27, 2);
insert into sys_user_role values (28, 2);
insert into sys_user_role values (29, 2);
insert into sys_user_role values (30, 2);
insert into sys_user_role values (31, 2);
insert into sys_user_role values (32, 2);
insert into sys_user_role values (33, 2);
insert into sys_user_role values (34, 2);
insert into sys_user_role values (35, 2);
insert into sys_user_role values (36, 2);
insert into sys_user_role values (37, 2);
insert into sys_user_role values (38, 2);
insert into sys_user_role values (39, 2);
insert into sys_user_role values (40, 2);
insert into sys_user_role values (41, 2);
insert into sys_user_role values (42, 2);
insert into sys_user_role values (43, 2);
insert into sys_user_role values (44, 2);
insert into sys_user_role values (45, 2);
insert into sys_user_role values (46, 2);
insert into sys_user_role values (47, 2);
insert into sys_user_role values (48, 2);
insert into sys_user_role values (49, 2);
insert into sys_user_role values (50, 2);
insert into sys_user_role values (51, 2);
insert into sys_user_role values (52, 2);
insert into sys_user_role values (53, 2);
insert into sys_user_role values (54, 2);
insert into sys_user_role values (55, 2);
insert into sys_user_role values (56, 2);
insert into sys_user_role values (57, 2);
insert into sys_user_role values (58, 2);
insert into sys_user_role values (59, 2);
insert into sys_user_role values (60, 2);
insert into sys_user_role values (61, 2);
insert into sys_user_role values (62, 2);
insert into sys_user_role values (63, 2);
insert into sys_user_role values (64, 2);
insert into sys_user_role values (65, 2);
insert into sys_user_role values (66, 2);
insert into sys_user_role values (67, 2);
insert into sys_user_role values (68, 2);
insert into sys_user_role values (69, 2);
insert into sys_user_role values (70, 2);
insert into sys_user_role values (71, 2);
insert into sys_user_role values (72, 2);
insert into sys_user_role values (73, 2);
insert into sys_user_role values (74, 2);
insert into sys_user_role values (75, 2);
insert into sys_user_role values (76, 2);
insert into sys_user_role values (77, 2);
insert into sys_user_role values (78, 2);
insert into sys_user_role values (79, 2);
insert into sys_user_role values (80, 2);
insert into sys_user_role values (81, 2);
insert into sys_user_role values (82, 2);
insert into sys_user_role values (83, 2);
insert into sys_user_role values (84, 2);
insert into sys_user_role values (85, 2);
insert into sys_user_role values (86, 2);
insert into sys_user_role values (87, 2);
insert into sys_user_role values (88, 2);
insert into sys_user_role values (89, 2);
insert into sys_user_role values (90, 2);
insert into sys_user_role values (91, 2);
insert into sys_user_role values (92, 2);
insert into sys_user_role values (93, 2);
insert into sys_user_role values (94, 2);
insert into sys_user_role values (95, 2);
insert into sys_user_role values (96, 2);
insert into sys_user_role values (97, 2);
insert into sys_user_role values (98, 2);
insert into sys_user_role values (99, 2);
insert into sys_user_role values (100, 2);
insert into sys_user_role values (101, 2);
insert into sys_user_role values (102, 2);
insert into sys_user_role values (103, 2);
insert into sys_user_role values (104, 2);
insert into sys_user_role values (105, 2);
insert into sys_user_role values (106, 2);
insert into sys_user_role values (107, 2);
insert into sys_user_role values (108, 2);
insert into sys_user_role values (109, 2);
insert into sys_user_role values (110, 2);
insert into sys_user_role values (111, 2);
insert into sys_user_role values (112, 2);
insert into sys_user_role values (113, 2);
insert into sys_user_role values (114, 2);
insert into sys_user_role values (115, 2);
insert into sys_user_role values (116, 2);
insert into sys_user_role values (117, 2);
insert into sys_user_role values (118, 2);
insert into sys_user_role values (119, 2);
insert into sys_user_role values (120, 2);
insert into sys_user_role values (121, 2);
insert into sys_user_role values (122, 2);
insert into sys_user_role values (123, 2);
insert into sys_user_role values (124, 2);
insert into sys_user_role values (125, 2);
insert into sys_user_role values (126, 2);
insert into sys_user_role values (127, 2);
insert into sys_user_role values (128, 2);
insert into sys_user_role values (129, 2);
insert into sys_user_role values (130, 2);
insert into sys_user_role values (131, 2);
insert into sys_user_role values (132, 2);
insert into sys_user_role values (133, 2);
insert into sys_user_role values (134, 2);
insert into sys_user_role values (135, 2);
insert into sys_user_role values (136, 2);
insert into sys_user_role values (137, 2);
insert into sys_user_role values (138, 2);
insert into sys_user_role values (139, 2);
insert into sys_user_role values (140, 2);
insert into sys_user_role values (141, 2);
insert into sys_user_role values (142, 2);
insert into sys_user_role values (143, 2);
insert into sys_user_role values (144, 2);
insert into sys_user_role values (145, 2);
insert into sys_user_role values (146, 2);
insert into sys_user_role values (147, 2);
insert into sys_user_role values (148, 2);
insert into sys_user_role values (149, 2);
insert into sys_user_role values (150, 2);


-- ----------------------------
-- 7、角色和菜单关联表  角色1-N菜单
-- ----------------------------
drop table if exists sys_role_menu;
create table sys_role_menu (
  role_id   bigint(20) not null comment '角色ID',
  menu_id   bigint(20) not null comment '菜单ID',
  primary key(role_id, menu_id)
) engine=innodb comment = '角色和菜单关联表';

-- ----------------------------
-- 初始化-角色和菜单关联表数据
-- ----------------------------
insert into sys_role_menu values ('2', '1000');
insert into sys_role_menu values ('2', '1001');
insert into sys_role_menu values ('2', '1017');

-- ----------------------------
-- 8、角色和部门关联表  角色1-N部门
-- ----------------------------
drop table if exists sys_role_dept;
create table sys_role_dept (
  role_id   bigint(20) not null comment '角色ID',
  dept_id   bigint(20) not null comment '部门ID',
  primary key(role_id, dept_id)
) engine=innodb comment = '角色和部门关联表';

-- ----------------------------
-- 初始化-角色和部门关联表数据
-- ----------------------------
insert into sys_role_dept values ('2', '100');
insert into sys_role_dept values ('2', '101');
insert into sys_role_dept values ('2', '102');
insert into sys_role_dept values ('2', '103');
insert into sys_role_dept values ('2', '104');
insert into sys_role_dept values ('2', '105');
insert into sys_role_dept values ('2', '106');
insert into sys_role_dept values ('2', '107');
insert into sys_role_dept values ('2', '108');
insert into sys_role_dept values ('2', '109');
insert into sys_role_dept values ('2', '110');
insert into sys_role_dept values ('2', '111');
insert into sys_role_dept values ('2', '112');
insert into sys_role_dept values ('2', '113');
insert into sys_role_dept values ('2', '114');
insert into sys_role_dept values ('2', '115');
insert into sys_role_dept values ('2', '116');
insert into sys_role_dept values ('2', '117');


-- ----------------------------
-- 9、用户与岗位关联表  用户1-N岗位
-- ----------------------------
drop table if exists sys_user_post;
create table sys_user_post
(
  user_id   bigint(20) not null comment '用户ID',
  post_id   bigint(20) not null comment '岗位ID',
  primary key (user_id, post_id)
) engine=innodb comment = '用户与岗位关联表';

-- ----------------------------
-- 初始化-用户与岗位关联表数据
-- ----------------------------
insert into sys_user_post values (1, 26);
insert into sys_user_post values (2, 1);
insert into sys_user_post values (2, 2);
insert into sys_user_post values (3, 3);
insert into sys_user_post values (4, 4);
insert into sys_user_post values (5, 5);
insert into sys_user_post values (6, 5);
insert into sys_user_post values (7, 6);
insert into sys_user_post values (8, 7);
insert into sys_user_post values (8, 8);
insert into sys_user_post values (8, 12);
insert into sys_user_post values (9, 9);
insert into sys_user_post values (10, 6);
insert into sys_user_post values (11, 6);
insert into sys_user_post values (12, 6);
insert into sys_user_post values (13, 10);
insert into sys_user_post values (13, 12);
insert into sys_user_post values (14, 10);
insert into sys_user_post values (14, 12);
insert into sys_user_post values (15, 19);
insert into sys_user_post values (16, 23);
insert into sys_user_post values (17, 23);
insert into sys_user_post values (18, 23);
insert into sys_user_post values (19, 23);
insert into sys_user_post values (20, 13);
insert into sys_user_post values (21, 13);
insert into sys_user_post values (22, 20);
insert into sys_user_post values (22, 23);
insert into sys_user_post values (23, 23);
insert into sys_user_post values (24, 23);
insert into sys_user_post values (25, 23);
insert into sys_user_post values (26, 23);
insert into sys_user_post values (27, 23);
insert into sys_user_post values (28, 13);
insert into sys_user_post values (29, 25);
insert into sys_user_post values (30, 24);
insert into sys_user_post values (31, 25);
insert into sys_user_post values (32, 12);
insert into sys_user_post values (33, 11);
insert into sys_user_post values (34, 26);
insert into sys_user_post values (35, 26);
insert into sys_user_post values (36, 26);
insert into sys_user_post values (37, 26);
insert into sys_user_post values (38, 12);
insert into sys_user_post values (39, 13);
insert into sys_user_post values (40, 26);
insert into sys_user_post values (41, 26);
insert into sys_user_post values (42, 26);
insert into sys_user_post values (43, 26);
insert into sys_user_post values (44, 12);
insert into sys_user_post values (45, 26);
insert into sys_user_post values (46, 26);
insert into sys_user_post values (47, 26);
insert into sys_user_post values (48, 26);
insert into sys_user_post values (49, 26);
insert into sys_user_post values (50, 26);
insert into sys_user_post values (51, 11);
insert into sys_user_post values (51, 12);
insert into sys_user_post values (52, 11);
insert into sys_user_post values (53, 5);
insert into sys_user_post values (54, 14);
insert into sys_user_post values (55, 14);
insert into sys_user_post values (56, 26);
insert into sys_user_post values (57, 26);
insert into sys_user_post values (58, 26);
insert into sys_user_post values (59, 26);
insert into sys_user_post values (60, 26);
insert into sys_user_post values (61, 26);
insert into sys_user_post values (62, 13);
insert into sys_user_post values (63, 13);
insert into sys_user_post values (64, 26);
insert into sys_user_post values (65, 26);
insert into sys_user_post values (66, 26);
insert into sys_user_post values (67, 26);
insert into sys_user_post values (68, 26);
insert into sys_user_post values (69, 26);
insert into sys_user_post values (70, 26);
insert into sys_user_post values (71, 26);
insert into sys_user_post values (72, 26);
insert into sys_user_post values (73, 26);
insert into sys_user_post values (74, 26);
insert into sys_user_post values (75, 26);
insert into sys_user_post values (76, 26);
insert into sys_user_post values (77, 26);
insert into sys_user_post values (78, 26);
insert into sys_user_post values (79, 26);
insert into sys_user_post values (80, 26);
insert into sys_user_post values (81, 26);
insert into sys_user_post values (82, 26);
insert into sys_user_post values (83, 12);
insert into sys_user_post values (84, 13);
insert into sys_user_post values (85, 26);
insert into sys_user_post values (86, 26);
insert into sys_user_post values (87, 26);
insert into sys_user_post values (88, 26);
insert into sys_user_post values (89, 26);
insert into sys_user_post values (90, 26);
insert into sys_user_post values (91, 26);
insert into sys_user_post values (92, 26);
insert into sys_user_post values (93, 26);
insert into sys_user_post values (94, 26);
insert into sys_user_post values (95, 26);
insert into sys_user_post values (96, 26);
insert into sys_user_post values (97, 26);
insert into sys_user_post values (98, 26);
insert into sys_user_post values (99, 26);
insert into sys_user_post values (100, 26);
insert into sys_user_post values (101, 26);
insert into sys_user_post values (102, 26);
insert into sys_user_post values (103, 12);
insert into sys_user_post values (104, 13);
insert into sys_user_post values (105, 26);
insert into sys_user_post values (106, 26);
insert into sys_user_post values (107, 26);
insert into sys_user_post values (108, 26);
insert into sys_user_post values (109, 26);
insert into sys_user_post values (110, 26);
insert into sys_user_post values (111, 26);
insert into sys_user_post values (112, 26);
insert into sys_user_post values (113, 26);
insert into sys_user_post values (114, 26);
insert into sys_user_post values (115, 15);
insert into sys_user_post values (116, 26);
insert into sys_user_post values (117, 26);
insert into sys_user_post values (118, 26);
insert into sys_user_post values (119, 26);
insert into sys_user_post values (120, 26);
insert into sys_user_post values (121, 26);
insert into sys_user_post values (122, 17);
insert into sys_user_post values (123, 17);
insert into sys_user_post values (124, 18);
insert into sys_user_post values (125, 26);
insert into sys_user_post values (126, 26);
insert into sys_user_post values (127, 26);
insert into sys_user_post values (128, 26);
insert into sys_user_post values (129, 26);
insert into sys_user_post values (130, 26);
insert into sys_user_post values (131, 26);
insert into sys_user_post values (132, 27);
insert into sys_user_post values (133, 27);
insert into sys_user_post values (134, 27);
insert into sys_user_post values (135, 27);
insert into sys_user_post values (136, 27);
insert into sys_user_post values (137, 27);
insert into sys_user_post values (138, 27);
insert into sys_user_post values (139, 27);
insert into sys_user_post values (140, 27);
insert into sys_user_post values (141, 15);
insert into sys_user_post values (142, 26);
insert into sys_user_post values (143, 26);
insert into sys_user_post values (144, 1);
insert into sys_user_post values (145, 2);
insert into sys_user_post values (146, 26);
insert into sys_user_post values (147, 26);
insert into sys_user_post values (148, 26);
insert into sys_user_post values (149, 26);
insert into sys_user_post values (150, 26);


-- ----------------------------
-- 10、操作日志记录
-- ----------------------------
drop table if exists sys_oper_log;
create table sys_oper_log (
  oper_id           bigint(20)      not null auto_increment    comment '日志主键',
  title             varchar(50)     default ''                 comment '模块标题',
  business_type     int(2)          default 0                  comment '业务类型（0其它 1新增 2修改 3删除）',
  method            varchar(100)    default ''                 comment '方法名称',
  request_method    varchar(10)     default ''                 comment '请求方式',
  operator_type     int(1)          default 0                  comment '操作类别（0其它 1后台用户 2手机端用户）',
  oper_name         varchar(50)     default ''                 comment '操作人员',
  dept_name         varchar(50)     default ''                 comment '部门名称',
  oper_url          varchar(255)    default ''                 comment '请求URL',
  oper_ip           varchar(128)    default ''                 comment '主机地址',
  oper_location     varchar(255)    default ''                 comment '操作地点',
  oper_param        varchar(2000)   default ''                 comment '请求参数',
  json_result       varchar(2000)   default ''                 comment '返回参数',
  status            int(1)          default 0                  comment '操作状态（0正常 1异常）',
  error_msg         varchar(2000)   default ''                 comment '错误消息',
  oper_time         datetime                                   comment '操作时间',
  cost_time         bigint(20)      default 0                  comment '消耗时间',
  primary key (oper_id),
  key idx_sys_oper_log_bt (business_type),
  key idx_sys_oper_log_s  (status),
  key idx_sys_oper_log_ot (oper_time)
) engine=innodb auto_increment=100 comment = '操作日志记录';


-- ----------------------------
-- 11、字典类型表
-- ----------------------------
drop table if exists sys_dict_type;
create table sys_dict_type
(
  dict_id          bigint(20)      not null auto_increment    comment '字典主键',
  dict_name        varchar(100)    default ''                 comment '字典名称',
  dict_type        varchar(100)    default ''                 comment '字典类型',
  status           char(1)         default '0'                comment '状态（0正常 1停用）',
  create_by        varchar(64)     default ''                 comment '创建者',
  create_time      datetime                                   comment '创建时间',
  update_by        varchar(64)     default ''                 comment '更新者',
  update_time      datetime                                   comment '更新时间',
  remark           varchar(500)    default null               comment '备注',
  primary key (dict_id),
  unique (dict_type)
) engine=innodb auto_increment=100 comment = '字典类型表';

insert into sys_dict_type values(1,  '用户性别', 'sys_user_sex',        '0', 'admin', sysdate(), '', null, '用户性别列表');
insert into sys_dict_type values(2,  '菜单状态', 'sys_show_hide',       '0', 'admin', sysdate(), '', null, '菜单状态列表');
insert into sys_dict_type values(3,  '系统开关', 'sys_normal_disable',  '0', 'admin', sysdate(), '', null, '系统开关列表');
insert into sys_dict_type values(4,  '任务状态', 'sys_job_status',      '0', 'admin', sysdate(), '', null, '任务状态列表');
insert into sys_dict_type values(5,  '任务分组', 'sys_job_group',       '0', 'admin', sysdate(), '', null, '任务分组列表');
insert into sys_dict_type values(6,  '系统是否', 'sys_yes_no',          '0', 'admin', sysdate(), '', null, '系统是否列表');
insert into sys_dict_type values(7,  '通知类型', 'sys_notice_type',     '0', 'admin', sysdate(), '', null, '通知类型列表');
insert into sys_dict_type values(8,  '通知状态', 'sys_notice_status',   '0', 'admin', sysdate(), '', null, '通知状态列表');
insert into sys_dict_type values(9,  '操作类型', 'sys_oper_type',       '0', 'admin', sysdate(), '', null, '操作类型列表');
insert into sys_dict_type values(10, '系统状态', 'sys_common_status',   '0', 'admin', sysdate(), '', null, '登录状态列表');
insert into sys_dict_type values (11, '项目经理级别', 'sys_user_pmlevel', '0', 'admin', '2024-01-08 15:42:02', '', null, null);
insert into sys_dict_type values (12, '工程师岗级', 'sys_user_engineerlevel', '0', 'admin', '2024-01-08 15:43:30', '', null, null);
insert into sys_dict_type values (13, '岗级', 'sys_user_postlevel', '0', 'admin', '2024-01-08 15:43:30', '', null, null);
insert into sys_dict_type values (14, '薪档', 'sys_user_salarylevel', '0', 'admin', '2024-01-08 15:43:30', '', null, null);
insert into sys_dict_type values (15, '技术职称', 'sys_user_titles', '0', 'admin', '2024-01-08 15:47:47', '', null, null);
insert into sys_dict_type values (16, '考核等级', 'cmc_accessment', '0', 'admin', '2024-01-08 15:58:22', '', null, null);
insert into sys_dict_type values (17, '技能掌握', 'cmc_skill', '0', 'admin', '2024-01-08 16:07:43', '', null, null);
insert into sys_dict_type values (18, '工作量', 'cmc_workload', '0', 'admin', '2024-01-08 16:08:51', '', null, null);
insert into sys_dict_type values (19, '承担角色', 'cmc_role', '0', 'admin', '2024-01-08 16:10:07', '', null, null);
insert into sys_dict_type values (20, '航飞机型', 'cmc_uav', '0', 'admin', '2024-01-12 15:34:18', '', null, null);

-- ----------------------------
-- 12、字典数据表
-- ----------------------------
drop table if exists sys_dict_data;
create table sys_dict_data
(
  dict_code        bigint(20)      not null auto_increment    comment '字典编码',
  dict_sort        int(4)          default 0                  comment '字典排序',
  dict_label       varchar(100)    default ''                 comment '字典标签',
  dict_value       varchar(100)    default ''                 comment '字典键值',
  dict_type        varchar(100)    default ''                 comment '字典类型',
  css_class        varchar(100)    default null               comment '样式属性（其他样式扩展）',
  list_class       varchar(100)    default null               comment '表格回显样式',
  is_default       char(1)         default 'N'                comment '是否默认（Y是 N否）',
  status           char(1)         default '0'                comment '状态（0正常 1停用）',
  create_by        varchar(64)     default ''                 comment '创建者',
  create_time      datetime                                   comment '创建时间',
  update_by        varchar(64)     default ''                 comment '更新者',
  update_time      datetime                                   comment '更新时间',
  remark           varchar(500)    default null               comment '备注',
  primary key (dict_code)
) engine=innodb auto_increment=100 comment = '字典数据表';

insert into sys_dict_data values (1, 1, '男', '0', 'sys_user_sex', '', '', 'Y', '0', 'admin', '2022-12-11 16:51:52', '', null, '性别男');
insert into sys_dict_data values (2, 2, '女', '1', 'sys_user_sex', '', '', 'N', '0', 'admin', '2022-12-11 16:51:52', '', null, '性别女');
insert into sys_dict_data values (3, 3, '未知', '2', 'sys_user_sex', '', '', 'N', '0', 'admin', '2022-12-11 16:51:52', '', null, '性别未知');
insert into sys_dict_data values (4, 1, '显示', '0', 'sys_show_hide', '', 'primary', 'Y', '0', 'admin', '2022-12-11 16:51:52', '', null, '显示菜单');
insert into sys_dict_data values (5, 2, '隐藏', '1', 'sys_show_hide', '', 'danger', 'N', '0', 'admin', '2022-12-11 16:51:52', '', null, '隐藏菜单');
insert into sys_dict_data values (6, 1, '正常', '0', 'sys_normal_disable', '', 'primary', 'Y', '0', 'admin', '2022-12-11 16:51:52', '', null, '正常状态');
insert into sys_dict_data values (7, 2, '停用', '1', 'sys_normal_disable', '', 'danger', 'N', '0', 'admin', '2022-12-11 16:51:52', '', null, '停用状态');
insert into sys_dict_data values (8, 1, '正常', '0', 'sys_job_status', '', 'primary', 'Y', '0', 'admin', '2022-12-11 16:51:52', '', null, '正常状态');
insert into sys_dict_data values (9, 2, '暂停', '1', 'sys_job_status', '', 'danger', 'N', '0', 'admin', '2022-12-11 16:51:52', '', null, '停用状态');
insert into sys_dict_data values (10, 1, '默认', 'DEFAULT', 'sys_job_group', '', '', 'Y', '0', 'admin', '2022-12-11 16:51:52', '', null, '默认分组');
insert into sys_dict_data values (11, 2, '系统', 'SYSTEM', 'sys_job_group', '', '', 'N', '0', 'admin', '2022-12-11 16:51:52', '', null, '系统分组');
insert into sys_dict_data values (12, 1, '是', 'Y', 'sys_yes_no', '', 'primary', 'Y', '0', 'admin', '2022-12-11 16:51:52', '', null, '系统默认是');
insert into sys_dict_data values (13, 2, '否', 'N', 'sys_yes_no', '', 'danger', 'N', '0', 'admin', '2022-12-11 16:51:52', '', null, '系统默认否');
insert into sys_dict_data values (14, 1, '通知', '1', 'sys_notice_type', '', 'warning', 'Y', '0', 'admin', '2022-12-11 16:51:52', '', null, '通知');
insert into sys_dict_data values (15, 2, '公告', '2', 'sys_notice_type', '', 'success', 'N', '0', 'admin', '2022-12-11 16:51:52', '', null, '公告');
insert into sys_dict_data values (16, 1, '正常', '0', 'sys_notice_status', '', 'primary', 'Y', '0', 'admin', '2022-12-11 16:51:52', '', null, '正常状态');
insert into sys_dict_data values (17, 2, '关闭', '1', 'sys_notice_status', '', 'danger', 'N', '0', 'admin', '2022-12-11 16:51:52', '', null, '关闭状态');
insert into sys_dict_data values (18, 99, '其他', '0', 'sys_oper_type', '', 'info', 'N', '0', 'admin', '2022-12-11 16:51:52', '', null, '其他操作');
insert into sys_dict_data values (19, 1, '新增', '1', 'sys_oper_type', '', 'info', 'N', '0', 'admin', '2022-12-11 16:51:52', '', null, '新增操作');
insert into sys_dict_data values (20, 2, '修改', '2', 'sys_oper_type', '', 'info', 'N', '0', 'admin', '2022-12-11 16:51:52', '', null, '修改操作');
insert into sys_dict_data values (21, 3, '删除', '3', 'sys_oper_type', '', 'danger', 'N', '0', 'admin', '2022-12-11 16:51:52', '', null, '删除操作');
insert into sys_dict_data values (22, 4, '授权', '4', 'sys_oper_type', '', 'primary', 'N', '0', 'admin', '2022-12-11 16:51:52', '', null, '授权操作');
insert into sys_dict_data values (23, 5, '导出', '5', 'sys_oper_type', '', 'warning', 'N', '0', 'admin', '2022-12-11 16:51:52', '', null, '导出操作');
insert into sys_dict_data values (24, 6, '导入', '6', 'sys_oper_type', '', 'warning', 'N', '0', 'admin', '2022-12-11 16:51:52', '', null, '导入操作');
insert into sys_dict_data values (25, 7, '强退', '7', 'sys_oper_type', '', 'danger', 'N', '0', 'admin', '2022-12-11 16:51:52', '', null, '强退操作');
insert into sys_dict_data values (26, 8, '生成代码', '8', 'sys_oper_type', '', 'warning', 'N', '0', 'admin', '2022-12-11 16:51:52', '', null, '生成操作');
insert into sys_dict_data values (27, 9, '清空数据', '9', 'sys_oper_type', '', 'danger', 'N', '0', 'admin', '2022-12-11 16:51:52', '', null, '清空操作');
insert into sys_dict_data values (28, 1, '成功', '0', 'sys_common_status', '', 'primary', 'N', '0', 'admin', '2022-12-11 16:51:52', '', null, '正常状态');
insert into sys_dict_data values (29, 2, '失败', '1', 'sys_common_status', '', 'danger', 'N', '0', 'admin', '2022-12-11 16:51:52', '', null, '停用状态');
insert into sys_dict_data values (30, 0, '一级', '0', 'sys_user_pmlevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:42:30', '', null, null);
insert into sys_dict_data values (31, 1, '二级', '1', 'sys_user_pmlevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:42:42', '', null, null);
insert into sys_dict_data values (32, 2, '三级', '2', 'sys_user_pmlevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:42:57', '', null, null);
insert into sys_dict_data values (33, 0, '一级', '0', 'sys_user_engineerlevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:45:14', '', null, null);
insert into sys_dict_data values (34, 1, '二级', '1', 'sys_user_engineerlevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:45:24', '', null, null);
insert into sys_dict_data values (35, 2, '三级', '2', 'sys_user_engineerlevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:45:37', '', null, null);
insert into sys_dict_data values (36, 3, '四级', '3', 'sys_user_engineerlevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:46:02', '', null, null);
insert into sys_dict_data values (37, 4, '五级', '4', 'sys_user_engineerlevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:46:24', '', null, null);
insert into sys_dict_data values (38, 5, '六级', '5', 'sys_user_engineerlevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:46:35', '', null, null);
insert into sys_dict_data values (39, 0, '一岗', '0', 'sys_user_postlevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:46:44', '', null, null);
insert into sys_dict_data values (40, 1, '二岗', '1', 'sys_user_postlevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:47:24', '', null, null);
insert into sys_dict_data values (41, 2, '三岗', '2', 'sys_user_postlevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:47:24', '', null, null);
insert into sys_dict_data values (42, 3, '四岗', '3', 'sys_user_postlevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:47:24', '', null, null);
insert into sys_dict_data values (43, 4, '五岗', '4', 'sys_user_postlevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:47:24', '', null, null);
insert into sys_dict_data values (44, 5, '六岗', '5', 'sys_user_postlevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:47:24', '', null, null);
insert into sys_dict_data values (45, 6, '七岗', '6', 'sys_user_postlevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:47:24', '', null, null);
insert into sys_dict_data values (46, 7, '八岗', '7', 'sys_user_postlevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:47:24', '', null, null);
insert into sys_dict_data values (47, 0, '一级', '0', 'sys_user_salarylevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:46:44', '', null, null);
insert into sys_dict_data values (48, 1, '二级', '1', 'sys_user_salarylevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:47:24', '', null, null);
insert into sys_dict_data values (49, 2, '三级', '2', 'sys_user_salarylevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:47:24', '', null, null);
insert into sys_dict_data values (50, 3, '四级', '3', 'sys_user_salarylevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:47:24', '', null, null);
insert into sys_dict_data values (51, 4, '五级', '4', 'sys_user_salarylevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:47:24', '', null, null);
insert into sys_dict_data values (52, 5, '六级', '5', 'sys_user_salarylevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:47:24', '', null, null);
insert into sys_dict_data values (53, 6, '七级', '6', 'sys_user_salarylevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:47:24', '', null, null);
insert into sys_dict_data values (54, 7, '八级', '7', 'sys_user_salarylevel', null, 'default', 'N', '0', 'admin', '2024-01-08 15:47:24', '', null, null);
insert into sys_dict_data values (55, 0, '正高', '0', 'sys_user_titles', null, 'default', 'N', '0', 'admin', '2024-01-08 15:48:08', '', null, null);
insert into sys_dict_data values (56, 1, '副高', '1', 'sys_user_titles', null, 'default', 'N', '0', 'admin', '2024-01-08 15:48:45', '', null, null);
insert into sys_dict_data values (57, 2, '中级', '2', 'sys_user_titles', null, 'default', 'N', '0', 'admin', '2024-01-08 15:48:57', '', null, null);
insert into sys_dict_data values (58, 3, '助工', '3', 'sys_user_titles', null, 'default', 'N', '0', 'admin', '2024-01-08 15:49:07', '', null, null);
insert into sys_dict_data values (59, 4, '注册测绘师', '4', 'sys_user_titles', null, 'default', 'N', '0', 'admin', '2024-01-08 15:49:30', '', null, null);
insert into sys_dict_data values (60, 5, '注册城乡规划师', '5', 'sys_user_titles', null, 'default', 'N', '0', 'admin', '2024-01-08 15:50:11', '', null, null);
insert into sys_dict_data values (61, 6, '注册岩土工程师', '6', 'sys_user_titles', null, 'default', 'N', '0', 'admin', '2024-01-08 15:50:58', '', null, null);
insert into sys_dict_data values (62, 7, '注册安全工程师', '7', 'sys_user_titles', null, 'default', 'N', '0', 'admin', '2024-01-08 15:51:13', '', null, null);
insert into sys_dict_data values (63, 8, '注册会计师', '8', 'sys_user_titles', null, 'default', 'N', '0', 'admin', '2024-01-08 15:51:36', '', null, null);
insert into sys_dict_data values (64, 0, '不合格', '0', 'cmc_accessment', null, 'default', 'N', '0', 'admin', '2024-01-08 15:58:47', '', null, null);
insert into sys_dict_data values (65, 1, '合格', '1', 'cmc_accessment', null, 'default', 'N', '0', 'admin', '2024-01-08 15:58:56', '', null, null);
insert into sys_dict_data values (66, 2, '良好', '2', 'cmc_accessment', null, 'default', 'N', '0', 'admin', '2024-01-08 15:59:08', '', null, null);
insert into sys_dict_data values (67, 3, '优秀', '3', 'cmc_accessment', null, 'default', 'N', '0', 'admin', '2024-01-08 15:59:23', '', null, null);
insert into sys_dict_data values (68, 0, '生疏', '0', 'cmc_skill', null, 'default', 'N', '0', 'admin', '2024-01-08 16:08:12', '', null, null);
insert into sys_dict_data values (69, 1, '较熟练', '1', 'cmc_skill', null, 'default', 'N', '0', 'admin', '2024-01-08 16:08:20', '', null, null);
insert into sys_dict_data values (70, 2, '熟练', '2', 'cmc_skill', null, 'default', 'N', '0', 'admin', '2024-01-08 16:08:28', '', null, null);
insert into sys_dict_data values (71, 3, '精通', '3', 'cmc_skill', null, 'default', 'N', '0', 'admin', '2024-01-08 16:09:06', '', null, null);
insert into sys_dict_data values (72, 0, '较少', '0', 'cmc_workload', null, 'default', 'N', '0', 'admin', '2024-01-08 16:09:14', '', null, null);
insert into sys_dict_data values (73, 1, '正常', '1', 'cmc_workload', null, 'default', 'N', '0', 'admin', '2024-01-08 16:09:22', '', null, null);
insert into sys_dict_data values (74, 2, '较多', '2', 'cmc_workload', null, 'default', 'N', '0', 'admin', '2024-01-08 16:09:30', '', null, null);
insert into sys_dict_data values (75, 0, '主办', '00', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-08 16:11:04', '', null, null);
insert into sys_dict_data values (76, 1, '参与', '01', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-08 16:11:15', '', null, null);
insert into sys_dict_data values (77, 2, '协办', '02', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-08 16:11:39', '', null, null);
insert into sys_dict_data values (78, 3, '常规项目', '03', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 09:15:45', '', null, null);
insert into sys_dict_data values (79, 4, '监测项目', '04', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 09:16:47', '', null, null);
insert into sys_dict_data values (80, 5, '调查项目', '05', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 09:19:17', '', null, null);
insert into sys_dict_data values (81, 6, '测量项目', '06', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 09:20:20', '', null, null);
insert into sys_dict_data values (82, 7, '其他项目', '07', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 09:20:32', '', null, null);
insert into sys_dict_data values (83, 8, '选点', '08', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 09:23:11', '', null, null);
insert into sys_dict_data values (84, 9, '埋石', '09', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 09:23:28', '', null, null);
insert into sys_dict_data values (85, 10, '观测', '10', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 09:23:44', '', null, null);
insert into sys_dict_data values (86, 11, '计算', '11', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 09:24:21', '', null, null);
insert into sys_dict_data values (87, 12, '检查', '12', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 09:24:33', '', null, null);
insert into sys_dict_data values (88, 13, '负责', '13', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 09:24:41', '', null, null);
insert into sys_dict_data values (89, 14, '前视', '14', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 09:48:05', '', null, null);
insert into sys_dict_data values (90, 15, '后视', '15', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 09:48:14', '', null, null);
insert into sys_dict_data values (91, 16, '水准', '16', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 09:48:38', '', null, null);
insert into sys_dict_data values (92, 17, '三角高程', '17', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 09:48:52', '', null, null);
insert into sys_dict_data values (93, 18, '实测', '18', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 09:49:09', '', null, null);
insert into sys_dict_data values (94, 19, '相控', '19', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 09:49:29', '', null, null);
insert into sys_dict_data values (95, 20, '调绘', '20', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 10:31:53', '', null, null);
insert into sys_dict_data values (96, 21, '测量', '21', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 10:32:57', '', null, null);
insert into sys_dict_data values (97, 22, '整理', '22', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 10:33:08', '', null, null);
insert into sys_dict_data values (98, 23, '主飞', '23', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 10:35:22', '', null, null);
insert into sys_dict_data values (99, 24, '协飞', '24', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 10:35:48', '', null, null);
insert into sys_dict_data values (100, 25, '作业', '25', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 10:43:01', '', null, null);
insert into sys_dict_data values (101, 26, '检查', '26', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 10:44:59', '', null, null);
insert into sys_dict_data values (102, 27, '负责', '27', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 10:45:12', '', null, null);
insert into sys_dict_data values (103, 28, '空三', '28', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 10:46:14', '', null, null);
insert into sys_dict_data values (104, 29, '建模', '29', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 10:46:42', '', null, null);
insert into sys_dict_data values (105, 30, '修模', '30', 'cmc_role', null, 'default', 'N', '0', 'admin', '2024-01-09 10:46:55', '', null, null);
insert into sys_dict_data values (106, 0, '傲视', '0', 'cmc_uav', null, 'default', 'N', '0', 'admin', '2024-01-12 15:35:35', '', null, null);
insert into sys_dict_data values (107, 1, '飞马', '1', 'cmc_uav', null, 'default', 'N', '0', 'admin', '2024-01-12 15:35:46', '', null, null);
insert into sys_dict_data values (108, 2, '华测', '2', 'cmc_uav', null, 'default', 'N', '0', 'admin', '2024-01-12 15:35:56', '', null, null);
insert into sys_dict_data values (109, 3, '其他', '3', 'cmc_uav', null, 'default', 'N', '0', 'admin', '2024-01-12 15:36:03', '', null, null);
insert into sys_dict_data values (202, 2, '用车审批流程', 'car', 'sys_process_category', null, 'default', 'N', '0', 'admin', '2024-01-23 10:56:19', '', null, null);
insert into sys_dict_data values (203, 3, '设备审批流程', 'device', 'sys_process_category', null, 'default', 'N', '0', 'admin', '2024-01-23 10:58:43', '', null, null);
insert into sys_dict_data values (204, 4, '项目流转流程', 'project', 'sys_process_category', null, 'default', 'N', '0', 'admin', '2024-01-23 10:59:48', '', null, null);
insert into sys_dict_data values (205, 5, '员工考核流程', 'assess', 'sys_process_category', null, 'default', 'N', '0', 'admin', '2024-01-23 11:02:55', '', null, null);

-- ----------------------------
-- 13、参数配置表
-- ----------------------------
drop table if exists sys_config;
create table sys_config (
  config_id         int(5)          not null auto_increment    comment '参数主键',
  config_name       varchar(100)    default ''                 comment '参数名称',
  config_key        varchar(100)    default ''                 comment '参数键名',
  config_value      varchar(500)    default ''                 comment '参数键值',
  config_type       char(1)         default 'N'                comment '系统内置（Y是 N否）',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time       datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间',
  remark            varchar(500)    default null               comment '备注',
  primary key (config_id)
) engine=innodb auto_increment=100 comment = '参数配置表';

insert into sys_config values(1, '主框架页-默认皮肤样式名称',     'sys.index.skinName',            'skin-blue',     'Y', 'admin', sysdate(), '', null, '蓝色 skin-blue、绿色 skin-green、紫色 skin-purple、红色 skin-red、黄色 skin-yellow' );
insert into sys_config values(2, '用户管理-账号初始密码',         'sys.user.initPassword',         '123456',        'Y', 'admin', sysdate(), '', null, '初始化密码 123456' );
insert into sys_config values(3, '主框架页-侧边栏主题',           'sys.index.sideTheme',           'theme-dark',    'Y', 'admin', sysdate(), '', null, '深色主题theme-dark，浅色主题theme-light' );
insert into sys_config values(4, '账号自助-验证码开关',           'sys.account.captchaEnabled',    'false',          'Y', 'admin', sysdate(), '', null, '是否开启验证码功能（true开启，false关闭）');
insert into sys_config values(5, '账号自助-是否开启用户注册功能', 'sys.account.registerUser',      'false',         'Y', 'admin', sysdate(), '', null, '是否开启注册用户功能（true开启，false关闭）');
insert into sys_config values(6, '用户登录-黑名单列表',           'sys.login.blackIPList',         '',              'Y', 'admin', sysdate(), '', null, '设置登录IP黑名单限制，多个匹配项以;分隔，支持匹配（*通配、网段）');


-- ----------------------------
-- 14、系统访问记录
-- ----------------------------
drop table if exists sys_logininfor;
create table sys_logininfor (
  info_id        bigint(20)     not null auto_increment   comment '访问ID',
  user_name      varchar(50)    default ''                comment '用户账号',
  ipaddr         varchar(128)   default ''                comment '登录IP地址',
  login_location varchar(255)   default ''                comment '登录地点',
  browser        varchar(50)    default ''                comment '浏览器类型',
  os             varchar(50)    default ''                comment '操作系统',
  status         char(1)        default '0'               comment '登录状态（0成功 1失败）',
  msg            varchar(255)   default ''                comment '提示消息',
  login_time     datetime                                 comment '访问时间',
  primary key (info_id),
  key idx_sys_logininfor_s  (status),
  key idx_sys_logininfor_lt (login_time)
) engine=innodb auto_increment=100 comment = '系统访问记录';


-- ----------------------------
-- 15、定时任务调度表
-- ----------------------------
drop table if exists sys_job;
create table sys_job (
  job_id              bigint(20)    not null auto_increment    comment '任务ID',
  job_name            varchar(64)   default ''                 comment '任务名称',
  job_group           varchar(64)   default 'DEFAULT'          comment '任务组名',
  invoke_target       varchar(500)  not null                   comment '调用目标字符串',
  cron_expression     varchar(255)  default ''                 comment 'cron执行表达式',
  misfire_policy      varchar(20)   default '3'                comment '计划执行错误策略（1立即执行 2执行一次 3放弃执行）',
  concurrent          char(1)       default '1'                comment '是否并发执行（0允许 1禁止）',
  status              char(1)       default '0'                comment '状态（0正常 1暂停）',
  create_by           varchar(64)   default ''                 comment '创建者',
  create_time         datetime                                 comment '创建时间',
  update_by           varchar(64)   default ''                 comment '更新者',
  update_time         datetime                                 comment '更新时间',
  remark              varchar(500)  default ''                 comment '备注信息',
  primary key (job_id, job_name, job_group)
) engine=innodb auto_increment=100 comment = '定时任务调度表';

insert into sys_job values(1, '系统默认（无参）', 'DEFAULT', 'ryTask.ryNoParams',        '0/10 * * * * ?', '3', '1', '1', 'admin', sysdate(), '', null, '');
insert into sys_job values(2, '系统默认（有参）', 'DEFAULT', 'ryTask.ryParams(\'ry\')',  '0/15 * * * * ?', '3', '1', '1', 'admin', sysdate(), '', null, '');
insert into sys_job values(3, '系统默认（多参）', 'DEFAULT', 'ryTask.ryMultipleParams(\'ry\', true, 2000L, 316.50D, 100)',  '0/20 * * * * ?', '3', '1', '1', 'admin', sysdate(), '', null, '');


-- ----------------------------
-- 16、定时任务调度日志表
-- ----------------------------
drop table if exists sys_job_log;
create table sys_job_log (
  job_log_id          bigint(20)     not null auto_increment    comment '任务日志ID',
  job_name            varchar(64)    not null                   comment '任务名称',
  job_group           varchar(64)    not null                   comment '任务组名',
  invoke_target       varchar(500)   not null                   comment '调用目标字符串',
  job_message         varchar(500)                              comment '日志信息',
  status              char(1)        default '0'                comment '执行状态（0正常 1失败）',
  exception_info      varchar(2000)  default ''                 comment '异常信息',
  create_time         datetime                                  comment '创建时间',
  primary key (job_log_id)
) engine=innodb comment = '定时任务调度日志表';


-- ----------------------------
-- 17、通知公告表
-- ----------------------------
drop table if exists sys_notice;
create table sys_notice (
  notice_id         int(4)          not null auto_increment    comment '公告ID',
  notice_title      varchar(50)     not null                   comment '公告标题',
  notice_type       char(1)         not null                   comment '公告类型（1通知 2公告）',
  notice_content    longblob        default null               comment '公告内容',
  status            char(1)         default '0'                comment '公告状态（0正常 1关闭）',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time       datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间',
  remark            varchar(255)    default null               comment '备注',
  primary key (notice_id)
) engine=innodb auto_increment=10 comment = '通知公告表';

-- ----------------------------
-- 初始化-公告信息表数据
-- ----------------------------
insert into sys_notice values('1', '温馨提醒：2018-07-01 若依新版本发布啦', '2', '新版本内容', '0', 'admin', sysdate(), '', null, '管理员');
insert into sys_notice values('2', '维护通知：2018-07-01 若依系统凌晨维护', '1', '维护内容',   '0', 'admin', sysdate(), '', null, '管理员');


-- ----------------------------
-- 18、代码生成业务表
-- ----------------------------
drop table if exists gen_table;
create table gen_table (
  table_id          bigint(20)      not null auto_increment    comment '编号',
  table_name        varchar(200)    default ''                 comment '表名称',
  table_comment     varchar(500)    default ''                 comment '表描述',
  sub_table_name    varchar(64)     default null               comment '关联子表的表名',
  sub_table_fk_name varchar(64)     default null               comment '子表关联的外键名',
  class_name        varchar(100)    default ''                 comment '实体类名称',
  tpl_category      varchar(200)    default 'crud'             comment '使用的模板（crud单表操作 tree树表操作）',
  tpl_web_type      varchar(30)     default ''                 comment '前端模板类型（element-ui模版 element-plus模版）',
  package_name      varchar(100)                               comment '生成包路径',
  module_name       varchar(30)                                comment '生成模块名',
  business_name     varchar(30)                                comment '生成业务名',
  function_name     varchar(50)                                comment '生成功能名',
  function_author   varchar(50)                                comment '生成功能作者',
  gen_type          char(1)         default '0'                comment '生成代码方式（0zip压缩包 1自定义路径）',
  gen_path          varchar(200)    default '/'                comment '生成路径（不填默认项目路径）',
  options           varchar(1000)                              comment '其它生成选项',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time 	    datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间',
  remark            varchar(500)    default null               comment '备注',
  primary key (table_id)
) engine=innodb auto_increment=1 comment = '代码生成业务表';


-- ----------------------------
-- 19、代码生成业务表字段
-- ----------------------------
drop table if exists gen_table_column;
create table gen_table_column (
  column_id         bigint(20)      not null auto_increment    comment '编号',
  table_id          bigint(20)                                 comment '归属表编号',
  column_name       varchar(200)                               comment '列名称',
  column_comment    varchar(500)                               comment '列描述',
  column_type       varchar(100)                               comment '列类型',
  java_type         varchar(500)                               comment 'JAVA类型',
  java_field        varchar(200)                               comment 'JAVA字段名',
  is_pk             char(1)                                    comment '是否主键（1是）',
  is_increment      char(1)                                    comment '是否自增（1是）',
  is_required       char(1)                                    comment '是否必填（1是）',
  is_insert         char(1)                                    comment '是否为插入字段（1是）',
  is_edit           char(1)                                    comment '是否编辑字段（1是）',
  is_list           char(1)                                    comment '是否列表字段（1是）',
  is_query          char(1)                                    comment '是否查询字段（1是）',
  query_type        varchar(200)    default 'EQ'               comment '查询方式（等于、不等于、大于、小于、范围）',
  html_type         varchar(200)                               comment '显示类型（文本框、文本域、下拉框、复选框、单选框、日期控件）',
  dict_type         varchar(200)    default ''                 comment '字典类型',
  sort              int                                        comment '排序',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time 	    datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间',
  primary key (column_id)
) engine=innodb auto_increment=1 comment = '代码生成业务表字段';


-- ----------------------------
-- 20、cmc考核表
-- ----------------------------
drop table if exists cmc_assess;
create table cmc_assess (
  assess_id				char(19)		not null		comment '总考核表id',
  user_id				bigint			default null	comment '用户id',
  project_id			char(19)		default null	comment '项目id',
  assess_time			datetime		default null	comment '考核时间（月份）',
  dept_assessment		char(1)			default null	comment '部门考核等级（不合格、合格、良好、优秀）',
  dept_advice			varchar(255)	default null	comment '部门考核意见',
  dept_time				datetime		default null	comment '部门考核时间',
  dept_assesser			varchar(30)		default null	comment '部门考核负责人',
  manager_assessment	char(1)			default null	comment '分管考核等级（不合格、合格、良好、优秀）',
  manager_advice		varchar(255)	default null	comment '分管考核意见',
  manager_time			datetime		default null	comment '分管考核时间',
  manager_assesser		varchar(10)		default null	comment '分管考核负责人',
  self_assess			varchar(255)	default null	comment '自述',
  fill_time				datetime		default null	comment '考核填报时间',
  other_work			varchar(255)	default null	comment '其他工作',
  primary key (assess_id)
) engine=innodb	comment = 'cmc考核表';


-- ----------------------------
-- 21、cmc考核内容表
-- ----------------------------
drop table if exists cmc_assess_content;
create table cmc_assess_content (
  content_id			char(21)		not null		comment '考核内容id(总考核表id+2位)',
  role					varchar(17)		default null	comment '承担角色',
  familiar				char(1)			default null	comment '熟练程度（生疏、熟练、精通）',
  remark				varchar(255)	default null	comment '备注',
  workload				char(1)			default null	comment '工作量（较少、正常、较多）',
  skill					char(1)			default null	comment '技能掌握（生疏、较熟练、熟练）',
  quality				char(1)			default null	comment '产品质量（不合格、合格、良好、优秀）',
  assessment			char(1)			default null	comment '岗位表现（不合格、合格、良好、优秀）',
  advice				varchar(255)	default null	comment '考核建议',
  primary key (content_id)
) engine=innodb	comment = 'cmc考核内容表';


-- ----------------------------
-- 22、cmc考核工作内容表
-- ----------------------------
drop table if exists cmc_assess_content_work;
create table cmc_assess_content_work (
  work_id				char(23)		not null		comment '工作内容id(考核内容id+2位)',
  work_load				varchar(10)		default null	comment '工作量',
  primary key (work_id)
) engine=innodb	comment = 'cmc考核工作内容表';


-- ----------------------------
-- 23、cmc项目表
-- ----------------------------
drop table if exists cmc_project;
create table cmc_project  (
  project_id			char(19)				not null			comment '项目id',
  project_number		varchar(10)				default null		comment '项目编号',
  project_name			varchar(50)				default null		comment '项目名称',
  project_leader		varchar(3)				default null		comment '项目负责人',
  is_finished			char(1)					default null		comment '项目状态（0进行中、1已结束）',
  project_source		char(1)					default null		comment '项目来源（0院内、1院外）',
  party_a				varchar(50)				default null		comment '甲方单位',
  contact_person		varchar(10)				default null		comment '联系人',
  telephone				char(11)				default null		comment '联系电话',
  project_type			varchar(20)				default null		comment '项目类型',
  project_level			char(1)					default null		comment '项目级别（0一般项目、1重大项目）',
  project_registrant	varchar(3)				default null		comment '项目登记人',
  undertaking_dept		varchar(20)				default null		comment '承担部门',
  create_time			datetime				default null		comment '项目登记时间',
  remark				varchar(255)				default null		comment '项目备注',
  primary key (project_id)
) engine = innodb comment = 'cmc项目表';

-- ----------------------------
-- 初始化-项目表数据
-- ----------------------------
insert into `cmc_project` values ('1633765257669246977', '2023C05', 'ML及JW水电工程建设征地实物指标调查配合测量', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1633768222907957249', '2023C12', '雅砻江两河口水电站水库泥沙监测系统建设工程、运行维护及泥沙淤积影响分析研究项目测量工作', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1633770346022699010', '2023W02', '雅砻江桐子林水电站水库泥沙断面测量', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1633770811569471490', '2023C01', '绵竹抽水蓄能电站工程区可研阶段地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1633771027018285057', '2023C02', '江油抽水蓄能电站可研阶段工程区1：1000地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1633771294472273922', '2023C17', '江油抽水蓄能水电站青江补水泵断面测量项目', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1633781742236073985', '2023C22', '牙根一级水电站坝址下游河段整治测绘工作', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1641355612560293889', '2023C26', '金沙江上游清洁能源基地叶巴滩混合式抽水蓄能电站地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1641805297456513026', '2023HY01', '航测遥感中心零星及借调项目', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1641807061123596290', '2023C24', '岷江干流张坎航电枢纽工程界桩测设工作', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1652690353125326849', '2023W13', '拉萨水环境项目测绘工作', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1658642869419769857', '2023C44', '老木孔水电站库区道路边沟坐标高程测量', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1658656258510553089', '2023C23', 'YX移民项目地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1673601192074149890', '2023C49', '甘孜抽水蓄能水电站地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1673601523608715266', '2023C54', '国能大渡河汉源永利坪光伏电站项目1：500地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1673601908515799042', '2023C52', '老木孔航电枢纽工程排涝区域1：2000地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1673602123545182210', '2023C53', '岷江干流张坎航电枢纽工程排涝区域1：2000地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1676948354560425986', '2023C58', '溪洛渡水电站雷波县元宝乡跑马坪村配合测量', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1676948591949643777', '2023C59', '老沟水库库容曲线测量', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1676948942941585410', '2023C57', '官地水电站地形图测绘本', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1679769237196898306', '2022C65', '大熊猫国家公园芦山县长石坝-南天门、鹿厂河-九里岗防火道路恢复重建工程地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1679769589929476097', '2022C66', '大熊猫国家公园芦山县保护管理设施项目地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1679769796872241154', '2023C60', '大渡河流域扩机电站坐标转换', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1679770747494465538', '2023C47', '绵竹抽水蓄能电站界桩测设工作', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1679772570787774466', '2023W24', '双流地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1685853339360690177', '2023W27', '简阳1：2000地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1685853709264748546', '2023C61', '革什扎河吉牛水电站8#支洞口地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1694527969734688770', '2023C63', '波罗水电站补充地形地类图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1694528325550080002', '2023C69', '金沙江岗托水电站地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1694633405980868610', '2023C66', '硬梁包水电站库区实物指标配合测量', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1694634867926499329', '2023C62', '铜街子水电站坝后段及渣场1：500地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1697108010087743490', '2023C72', '江油抽水蓄能电站界桩测设工作', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1697109013545615362', '2023C73', '雅江抽水蓄能电站规划阶段地形图测量', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1702491945512730626', '2023C76', '牙根二级水电站1：2000地形地类图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1702492292125818881', '2023C75', '金沙江波罗水电站集镇新址国省干道占地范围公路配合测量', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1707211932139782146', '2023C78', '双江口混合式抽水蓄能电站地形图测绘', null, '1', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1707626752387317762', '2023C74', '攀枝花市仁和区南部一期280MW光伏项目1:500地形图测绘', null, '1', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1713455412201652225', '2023C79', '雅江抽水蓄能电站（茈卡村）地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1715703538933301249', '2023C80', '安徽省西形冲抽水蓄能电站可研阶段地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1718965187043655682', '2023C82', '叙州区抽水蓄能电站1：2000地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1718973009617747970', '2023C83', 'YJ电站施工图阶段1:500地形图补测工作', null, '1', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1721876576657735682', '2023C89', '雅下多雄拉隧洞部位控制点复核工作', null, '1', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1729523067262074882', '2023C86', '叶巴滩水电站连接道路硬化改建工程1：2000地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1729523327594135553', '2023C88', '大邑抽水蓄能水电站可研阶段地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1729523650169667586', '2023C90', '牙根二级水电站集镇新址、泥石流沟、取水线路地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1729523884455100418', '2023C93', '新龙抽水蓄能电站地形图测绘（新站址）', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1730092422756564993', '2023C87', '中核汇能昭觉县264MW风电+宁南县49MW风电项目', null, '1', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1731465142576611330', '2023C94', 'JW梯级电站可研阶段地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1737454765236813825', '2023C101', 'ML水电站可研阶段1：1000地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1739658607567306754', '2023W37', '大唐长河坝115万千瓦光伏项目1:2000地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1739658998220587009', '2023C99', '两河口水电站库区6座复建桥梁桥址河道断面形态以及桥墩、桥台的形态测量', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1739961827233628162', '2023C97', '西藏江达鲁格一期120万kW光伏项目场址地形图', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1741421858231681026', '2023C98', '藏东南（玉察）水风光一体化基地八宿2、3号光伏地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1741422198586867714', '2023C95', '藏东南（玉察）水风光一体化基地八宿8号光伏地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1741422566360219650', '2023C96', '藏东南（玉察）水风光一体化基地八宿12号光伏地形图测绘（Ⅰ标段测绘）', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1752902350986543105', '2024HY01', '航测遥感中心借调、零星项目', null, '0', null, null, null, null, null, null, null, null, null, null);
insert into `cmc_project` values ('1752903021416677378', '2024W02', '凤山平乐风电场地形图测绘', null, '0', null, null, null, null, null, null, null, null, null, null);

-- ----------------------------
-- 24、cmc项目内容表
-- ----------------------------
drop table if exists `cmc_project_work`;
create table `cmc_project_work`  (
  `work_id`			char(19)		not null		comment '工作内容id',
  `project_id`		char(19)		not null		comment '项目id',
  `content`			varchar(255)	default null	comment '工作内容',
  `scale`			varchar(10)		default null	comment '等级或比例尺',
  `unit`			varchar(10)		default null	comment '单位',
  `workload`		varchar(10)		default null	comment '工作量',
  `deadline`		datetime		default null	comment '要求完成时间',
  `remark`			varchar(255)		default null	comment '工作内容备注',
  primary key (`work_id`)
) engine = innodb comment = 'cmc项目内容表';

-- ----------------------------
-- 初始化-项目内容表
-- ----------------------------

-- ----------------------------
-- 25、cmc车辆信息表
-- ----------------------------
drop table if exists `cmc_car`;
create table `cmc_car`  (
  `car_id`			int					not null auto_increment		comment '车辆id',
  `license_plate`	varchar(8)			default null				comment '车牌号',
  `driver`			bigint				default null				comment '驾驶员（常用）',
  `cost`			decimal(10,2)		default null				comment '总价',
  `expect_life`		int					default null				comment '预计使用年限',
  `series`			varchar(10)			default null				comment '车系',
  `level`			varchar(10)			default null				comment '车级',
  primary key (`car_id`)
) engine = innodb comment = 'cmc车辆信息表';

-- ----------------------------
-- 初始化-车辆信息表数据
-- ----------------------------

-- ----------------------------
-- 26、cmc用车审批表
-- ----------------------------
drop table if exists `cmc_car_approval`;
create table `cmc_car_approval`  (
  `car_apply_id`		char(19)		not null		comment '用车申请id',
  `applier`				bigint			default null	comment '申请人',
  `cars`				varchar(10)		default null	comment '车辆id',
  `drivers`				varchar(20)		default null	comment '驾驶员id',
  `project_number`		varchar(10)		default null	comment '项目编号',
  `apply_reason`		varchar(255)	default null 	comment '用车事由',
  `passengers`			int				default null 	comment '人数',
  `begin_date`			date			default null 	comment '开始日期',
  `begin_halfday`		char(2)			default null 	comment '开始日期上/下午',
  `end_date`			date			default null 	comment '结束日期',
  `end_halfday`			char(2)			default null 	comment '结束日期上/下午',
  `days`				float			default null 	comment '天数',
  `dept_user_id`		bigint			default null 	comment '部门审批人',
  `dept_comment`		varchar(255)	default null 	comment '部门审批意见',
  `manager_user_id`		bigint			default null 	comment '分管审批人',
  `manager_comment`		varchar(255)	default null 	comment '分管审批意见',
  `union_user_id`		bigint			default null 	comment '工会审批人',
  `union_comment`		varchar(255)	default null 	comment '工会审批意见',
  `dispatcher`			bigint			default null	comment '调度员',
  `dispatch_comment`	varchar(255)	default null 	comment '调度审批意见',
  `estimate_cost`		decimal(10,2)	default null	comment '预计用车成本',
  primary key (`car_apply_id`)
) engine = innodb comment = 'cmc用车审批表';

-- ----------------------------
-- 初始化-用车审批表数据
-- ----------------------------

-- ----------------------------
-- 27、cmc设备信息表
-- ----------------------------
drop table if exists `cmc_device`;
create table `cmc_device`  (
  `device_id`		int					not null auto_increment		comment '设备id',
  `code`			varchar(20)			default null				comment '设备编号',
  `type`			varchar(10)			default null				comment '设备类别',
  `cost`			decimal(10,2)		default null				comment '总价',
  `expect_life`		int					default null				comment '预计使用年限',
  `series`			varchar(20)			default null				comment '设备系列',
  primary key (`device_id`)
) engine = innodb comment = 'cmc设备信息表';

-- ----------------------------
-- 初始化-设备信息表数据
-- ----------------------------

-- ----------------------------
-- 28、cmc设备审批表
-- ----------------------------
drop table if exists `cmc_device_approval`;
create table `cmc_device_approval`  (
  `device_apply_id`		char(19)		not null		comment '设备申请id',
  `applier`				bigint			default null	comment '申请人',
  `device_id`			varchar(10)		default null	comment '设备id',
  `project_number`		varchar(10)		default null	comment '项目编号',
  `apply_reason`		varchar(255)	default null 	comment '申领事由',
  `begin_date`			date			default null 	comment '开始日期',
  `begin_halfday`		char(2)			default null 	comment '开始日期上/下午',
  `end_date`			date			default null 	comment '结束日期',
  `end_halfday`			char(2)			default null 	comment '结束日期上/下午',
  `days`				float			default null 	comment '天数',
  `dept_user_id`		bigint			default null 	comment '部门审批人',
  `dept_comment`		varchar(255)	default null 	comment '部门审批意见',
  `manager_user_id`		bigint			default null 	comment '分管审批人',
  `manager_comment`		varchar(255)	default null 	comment '分管审批意见',
  `dispatcher`			bigint			default null	comment '调度员',
  `dispatch_comment`	varchar(255)	default null 	comment '调度审批意见',
  `estimate_cost`		decimal(10,2)	default null	comment '预计设备成本',
  primary key (`device_apply_id`)
) engine = innodb comment = 'cmc设备审批表';

-- ----------------------------
-- 初始化-设备审批表数据
-- ----------------------------

-- ----------------------------
-- 29、cmc用户历史表
-- ----------------------------
drop table if exists `cmc_user_history`;
create table `cmc_user_history`  (
  `history_id`		int				not null	auto_increment 	comment '历史id',
  `user_id`			bigint			default null				comment '用户id',
  `titiles`			varchar(9)		default null				comment '技术职称（0正高、1副高、2中级、3助工、4注测、5注规、6注岩、7注安、8注会）',
  `pm_level`		char(1)			default null				comment '项目经理级别（0一、1二、2三）',
  `engineer_level`	char(1) 		default null				comment '工程师岗级（0一、1二、2三、3四、4五、5六）',
  `post_level`		char(1) 		default null				comment '岗级（0一、1二、2三、3四、4五、5六、6七、7八）',
  `salary_level`	char(1) 		default null				comment '薪档（0一、1二、2三、3四、4五、5六、6七、7八）',
  `update_time`		datetime		default null				comment '更新时间',
  `update_reason`	char(1) 		default null				comment '更新原因（0误录修改、1正常调整）',
  primary key (`history_id`)
) engine = innodb comment = 'cmc用户历史表';

-- ----------------------------
-- 初始化-用户历史表数据
-- ----------------------------
